@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2000-2002 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -77,19 +77,23 @@ report_info(
 	char		*mntpoint,
 	int		unwritten,
 	int		dirversion,
+	int		logversion,
 	int		isint)
 {
 	printf("meta-data=%-22s isize=%-6d agcount=%d, agsize=%d blks\n"
 	       "data     =%-22s bsize=%-6d blocks=%lld, imaxpct=%d\n"
 	       "         =%-22s sunit=%-6d swidth=%d blks, unwritten=%d\n"
 	       "naming   =version %-14d bsize=%-6d\n"
-	       "log      =%-22s bsize=%-6d blocks=%d\n"
+	       "log      =%-22s bsize=%-6d blocks=%d version=%d\n"
+	       "         =%-22s sunit=%d blks\n"
 	       "realtime =%-22s extsz=%-6d blocks=%lld, rtextents=%lld\n",
 	       mntpoint, geo.inodesize, geo.agcount, geo.agblocks,
 	       "", geo.blocksize, (long long)geo.datablocks, geo.imaxpct,
 	       "", geo.sunit, geo.swidth, unwritten,
 	       dirversion, geo.dirblocksize,
 	       isint ? "internal" : "external", geo.blocksize, geo.logblocks,
+	       logversion,
+	       "", geo.logsunit / geo.blocksize,
 	       geo.rtblocks ? "external" : "none",
 	       geo.rtextsize * geo.blocksize,
 	       (long long)geo.rtblocks, (long long)geo.rtextents);
@@ -170,6 +174,7 @@ main(int argc, char **argv)
 	long long		ddsize;	/* device size in 512-byte blocks */
 	int			dflag;	/* -d flag */
 	int			dirversion; /* directory version number */
+	int			logversion; /* log version number */
 	long long		dlsize;	/* device size in 512-byte blocks */
 	long long		drsize;	/* device size in 512-byte blocks */
 	long long		dsize;	/* new data size in fs blocks */
@@ -265,17 +270,29 @@ main(int argc, char **argv)
 
 	/* get the current filesystem size & geometry */
 	if (ioctl(ffd, XFS_IOC_FSGEOMETRY, &geo) < 0) {
-		fprintf(stderr, "%s: cannot determine geometry of filesystem"
-			" mounted at %s: %s\n",
-			progname, fname, strerror(errno));
-		exit(1);
+		/*
+		 * OK, new ioctl barfed - back off and try earlier version
+		 * as we're probably running an older kernel version.
+		 * Only field added in the v2 geometry ioctl is "logsunit"
+		 * so we'll zero that out for later display (as zero).
+		 */
+		geo.logsunit = 1;	/* 1 BB */
+		if (ioctl(ffd, XFS_IOC_FSGEOMETRY_V1, &geo) < 0) {
+			fprintf(stderr,
+				"%s: cannot determine geometry of filesystem"
+				" mounted at %s: %s\n",
+				progname, fname, strerror(errno));
+			exit(1);
+		}
 	}
 	isint = geo.logstart > 0;
 	unwritten = geo.flags & XFS_FSOP_GEOM_FLAGS_EXTFLG ? 1 : 0;
 	dirversion = geo.flags & XFS_FSOP_GEOM_FLAGS_DIRV2 ? 2 : 1;
+	logversion = geo.flags & XFS_FSOP_GEOM_FLAGS_LOGV2 ? 2 : 1;
 
 	if (nflag) {
-		report_info(geo, fname, unwritten, dirversion, isint);
+		report_info(geo, fname, unwritten, dirversion, logversion, 
+				isint);
 		exit(0);
 	}
 
@@ -310,7 +327,7 @@ main(int argc, char **argv)
 		exit(1);
 	}
 
-	report_info(geo, fname, unwritten, dirversion, isint);
+	report_info(geo, fname, unwritten, dirversion, logversion, isint);
 
 	ddsize = xi.dsize;
 	dlsize = ( xi.logBBsize? xi.logBBsize :
@@ -455,7 +472,7 @@ main(int argc, char **argv)
 		}
 	}
 
-	if (ioctl(ffd, XFS_IOC_FSGEOMETRY, &ngeo) < 0) {
+	if (ioctl(ffd, XFS_IOC_FSGEOMETRY_V1, &ngeo) < 0) {
 		fprintf(stderr, "%s: ioctl failed - XFS_IOC_FSGEOMETRY: %s\n",
 			progname, strerror(errno));
 		exit(1);
