@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2000-2002 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -36,7 +36,6 @@
 
 #include <xfs_fs.h>
 #include <xfs_types.h>
-#include <arch.h>
 #include <xfs_arch.h>
 #include <xfs_sb.h>
 #include <xfs_bit.h>
@@ -69,12 +68,15 @@
 #include <xfs_inode.h>
 #include <xfs_buf_item.h>
 #include <xfs_inode_item.h>
-#include <xfs_cred.h>
 #include <xfs_bmap.h>
 #include <xfs_imap.h>
 #include <xfs_log.h>
 #include <xfs_log_priv.h>
 
+#ifndef XFS_SUPER_MAGIC
+#define XFS_SUPER_MAGIC 0x58465342
+#endif
+
 /*
  * Argument structure for libxfs_init().
  */
@@ -117,7 +119,8 @@ extern void	libxfs_device_zero (dev_t, xfs_daddr_t, uint);
 extern void	libxfs_device_close (dev_t);
 
 /* check or write log footer: specify device, log size in blocks & uuid */
-extern int	libxfs_log_clear (dev_t, xfs_daddr_t, uint, uuid_t *, int);
+extern int	libxfs_log_clear (dev_t, xfs_daddr_t, uint, uuid_t *,
+				int, int, int);
 
 /* 
  * Define a user-level mount structure with all we need
@@ -129,7 +132,7 @@ typedef struct xfs_mount {
 	int			m_bsize;	/* fs logical block size */
 	xfs_agnumber_t		m_agfrotor;	/* last ag where space found */
 	xfs_agnumber_t		m_agirotor;	/* last ag dir inode alloced */
-	xfs_agnumber_t	m_maxagi;		/* highest inode alloc group */
+	xfs_agnumber_t		m_maxagi;	/* highest inode alloc group */
 	uint			m_rsumlevels;	/* rt summary levels */
 	uint			m_rsumsize;	/* size of rt summary, bytes */
 	struct xfs_inode	*m_rbmip;	/* pointer to bitmap inode */
@@ -169,6 +172,7 @@ typedef struct xfs_mount {
 	__uint64_t		m_maxicount;	/* maximum inode count */
 	int			m_dalign;	/* stripe unit */
 	int			m_swidth;	/* stripe width */
+	int			m_lstripemask;	/* log stripe mask */
 	int			m_sinoalign;	/* stripe unit inode alignmnt */
 	int			m_dir_magicpct;	/* 37% of the dir blocksize */
 	__uint8_t		m_dirversion;	/* 1 or 2 */
@@ -302,9 +306,9 @@ extern int	libxfs_trans_read_buf (xfs_mount_t *, xfs_trans_t *, dev_t,
  * Simple memory interface
  */
 typedef struct xfs_zone {
-	int	zone_unitsize;  /* Size in bytes of zone unit           */
-	char	*zone_name;     /* tag name                             */
-        int     allocated;      /* debug: How many currently allocated  */
+	int	zone_unitsize;	/* Size in bytes of zone unit           */
+	char	*zone_name;	/* tag name                             */
+	int	allocated;	/* debug: How many currently allocated  */
 } xfs_zone_t;
 
 extern xfs_zone_t	*libxfs_zone_init (int, char *);
