@@ -1,47 +1,47 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ * Copyright (c) 2000-2002 Silicon Graphics, Inc.  All Rights Reserved.
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
- * or the like.  Any license provided herein, whether implied or
+ * or the like.	 Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
-#ifndef	__XFS_INODE_H__
-#define	__XFS_INODE_H__
+#ifndef __XFS_INODE_H__
+#define __XFS_INODE_H__
 
 /*
  * File incore extent information, present for each of data & attr forks.
  */
-#define	XFS_INLINE_EXTS	2
-#define	XFS_INLINE_DATA	32
+#define XFS_INLINE_EXTS 2
+#define XFS_INLINE_DATA 32
 typedef struct xfs_ifork {
-	int			if_bytes; 	/* bytes in if_u1 */
+	int			if_bytes;	/* bytes in if_u1 */
 	int			if_real_bytes;	/* bytes allocated in if_u1 */
 	xfs_bmbt_block_t	*if_broot;	/* file's incore btree root */
-	short			if_broot_bytes;	/* bytes allocated for root */
+	short			if_broot_bytes; /* bytes allocated for root */
 	unsigned char		if_flags;	/* per-fork flags */
 	unsigned char		if_ext_max;	/* max # of extent records */
 	xfs_extnum_t		if_lastex;	/* last if_extents used */
@@ -62,26 +62,26 @@ typedef struct xfs_ifork {
 /*
  * Flags for xfs_ichgtime().
  */
-#define	XFS_ICHGTIME_MOD	0x1	/* data fork modification timestamp */
-#define	XFS_ICHGTIME_ACC	0x2	/* data fork access timestamp */
-#define	XFS_ICHGTIME_CHG	0x4	/* inode field change timestamp */
+#define XFS_ICHGTIME_MOD	0x1	/* data fork modification timestamp */
+#define XFS_ICHGTIME_ACC	0x2	/* data fork access timestamp */
+#define XFS_ICHGTIME_CHG	0x4	/* inode field change timestamp */
 
 /*
  * Per-fork incore inode flags.
  */
-#define	XFS_IFINLINE	0x0001	/* Inline data is read in */
-#define	XFS_IFEXTENTS	0x0002	/* All extent pointers are read in */
-#define	XFS_IFBROOT	0x0004	/* i_broot points to the bmap b-tree root */
+#define XFS_IFINLINE	0x0001	/* Inline data is read in */
+#define XFS_IFEXTENTS	0x0002	/* All extent pointers are read in */
+#define XFS_IFBROOT	0x0004	/* i_broot points to the bmap b-tree root */
 
 /*
  * Flags for xfs_imap() and xfs_dilocate().
  */
-#define	XFS_IMAP_LOOKUP		0x1
+#define XFS_IMAP_LOOKUP		0x1
 
 /*
  * Maximum number of extent pointers in if_u1.if_extents.
  */
-#define	XFS_MAX_INCORE_EXTENTS	32768
+#define XFS_MAX_INCORE_EXTENTS	32768
 
 
 #ifdef __KERNEL__
@@ -98,7 +98,6 @@ struct xfs_inode_log_item;
 struct xfs_mount;
 struct xfs_trans;
 struct xfs_dquot;
-struct pm;
 
 
 /*
@@ -119,23 +118,6 @@ typedef struct xfs_gap {
 	xfs_extlen_t	xg_count_fsb;
 } xfs_gap_t;
 
-/*
- * This structure is used to hold common pieces of the buffer
- * and file for xfs_dio_write and xfs_dio_read.
- */
-typedef	struct xfs_dio {
-	struct xfs_buf	*xd_bp;
-	bhv_desc_t	*xd_bdp;
-	struct xfs_inode *xd_ip;
-	struct xfs_iocore *xd_io;
-	struct cred	*xd_cr;
-	struct pm	*xd_pmp;
-	int		xd_blkalgn;
-	int		xd_ioflag;
-	xfs_off_t	xd_start;
-	size_t		xd_length;
-} xfs_dio_t;
-
 typedef struct dm_attrs_s {
 	__uint32_t	da_dmevmask;	/* DMIG event mask */
 	__uint16_t	da_dmstate;	/* DMIG state info */
@@ -162,8 +144,8 @@ typedef struct xfs_iocore {
 
 } xfs_iocore_t;
 
-#define        io_dmevmask     io_dmattrs.da_dmevmask
-#define        io_dmstate      io_dmattrs.da_dmstate
+#define	       io_dmevmask     io_dmattrs.da_dmevmask
+#define	       io_dmstate      io_dmattrs.da_dmstate
 
 #define XFS_IO_INODE(io)	((xfs_inode_t *) ((io)->io_obj))
 #define XFS_IO_DCXVN(io)	((dcxvn_t *) ((io)->io_obj))
@@ -193,12 +175,9 @@ extern void xfs_iocore_inode_reinit(struct xfs_inode *);
  */
 typedef struct xfs_ihash {
 	struct xfs_inode	*ih_next;	
-	mrlock_t		ih_lock;
+	rwlock_t		ih_lock;
 	uint			ih_version;
 } xfs_ihash_t;
-#if defined(MP)
-#pragma set type attribute xfs_ihash align=128
-#endif
 
 /*
  * Inode hashing and hash bucket locking.
@@ -207,7 +186,7 @@ typedef struct xfs_ihash {
 #define XFS_IHASH(mp,ino) ((mp)->m_ihash + (((uint)ino) % (mp)->m_ihsize))
 
 /*
- * This is the xfs inode cluster hash.  This hash is used by xfs_iflush to
+ * This is the xfs inode cluster hash.	This hash is used by xfs_iflush to
  * find inodes that share a cluster and can be flushed to disk at the same
  * time.
  */
@@ -215,7 +194,7 @@ typedef struct xfs_ihash {
 typedef struct xfs_chashlist {
 	struct xfs_chashlist	*chl_next;
 	struct xfs_inode	*chl_ip;
-	xfs_daddr_t		chl_blkno;	/* starting block number of 
+	xfs_daddr_t		chl_blkno;	/* starting block number of
 						 * the cluster */
 #ifdef DEBUG
 	struct xfs_buf		*chl_buf;	/* debug: the inode buffer */
@@ -233,7 +212,7 @@ typedef struct xfs_chash {
  * Most of the on-disk inode is embedded in the i_d field.
  *
  * The extent pointers/inline file space, however, are managed
- * separately.  The memory for this information is pointed to by
+ * separately.	The memory for this information is pointed to by
  * the if_u1 unions depending on the type of the data.
  * This is used to linearize the array of extents for fast in-core
  * access.  This is used until the file's number of extents
@@ -243,8 +222,8 @@ typedef struct xfs_chash {
  * Other state kept in the in-core inode is used for identification,
  * locking, transactional updating, etc of the inode.
  *
- * Generally, we do not want to hold the i_rlock while holding the 
- * i_ilock. Hierarchy is i_iolock followed by i_rlock. 
+ * Generally, we do not want to hold the i_rlock while holding the
+ * i_ilock. Hierarchy is i_iolock followed by i_rlock.
  *
  * xfs_iptr_t contains all the inode fields upto and including the
  * i_mnext and i_mprev fields, it is used as a marker in the inode
@@ -301,7 +280,7 @@ typedef struct xfs_inode {
 	unsigned char		i_update_core;	/* timestamps/size is dirty */
 	unsigned char		i_update_size;	/* di_size field is dirty */
 	unsigned int		i_gen;		/* generation count */
-	unsigned int		i_delayed_blks;	/* count of delay alloc blks */
+	unsigned int		i_delayed_blks; /* count of delay alloc blks */
 
 	xfs_dinode_core_t	i_d;		/* most of ondisk inode */
 	xfs_chashlist_t		*i_chash;	/* cluster hash list header */
@@ -313,7 +292,7 @@ typedef struct xfs_inode {
 	struct ktrace		*i_xtrace;	/* inode extent list trace */
 	struct ktrace		*i_btrace;	/* inode bmap btree trace */
 	struct ktrace		*i_rwtrace;	/* inode read/write trace */
-	struct ktrace		*i_strat_trace;	/* inode strat_write trace */
+	struct ktrace		*i_strat_trace; /* inode strat_write trace */
 	struct ktrace		*i_lock_trace;	/* inode lock/unlock trace */
 	struct ktrace		*i_dir_trace;	/* inode directory trace */
 #endif /* DEBUG */
@@ -327,57 +306,57 @@ typedef struct xfs_inode {
  */
 #if XFS_WANT_FUNCS || (XFS_WANT_SPACE && XFSSO_XFS_IFORK_PTR)
 xfs_ifork_t *xfs_ifork_ptr(xfs_inode_t *ip, int w);
-#define	XFS_IFORK_PTR(ip,w)   		xfs_ifork_ptr(ip,w)
+#define XFS_IFORK_PTR(ip,w)		xfs_ifork_ptr(ip,w)
 #else
-#define	XFS_IFORK_PTR(ip,w)   ((w) == XFS_DATA_FORK ? &(ip)->i_df : (ip)->i_afp)
+#define XFS_IFORK_PTR(ip,w)   ((w) == XFS_DATA_FORK ? &(ip)->i_df : (ip)->i_afp)
 #endif
 #if XFS_WANT_FUNCS || (XFS_WANT_SPACE && XFSSO_XFS_IFORK_Q)
 int xfs_ifork_q(xfs_inode_t *ip);
-#define	XFS_IFORK_Q(ip)			xfs_ifork_q(ip)
+#define XFS_IFORK_Q(ip)			xfs_ifork_q(ip)
 #else
-#define	XFS_IFORK_Q(ip)			XFS_CFORK_Q(&(ip)->i_d)
+#define XFS_IFORK_Q(ip)			XFS_CFORK_Q(&(ip)->i_d)
 #endif
 #if XFS_WANT_FUNCS || (XFS_WANT_SPACE && XFSSO_XFS_IFORK_DSIZE)
 int xfs_ifork_dsize(xfs_inode_t *ip);
-#define	XFS_IFORK_DSIZE(ip)		xfs_ifork_dsize(ip)
+#define XFS_IFORK_DSIZE(ip)		xfs_ifork_dsize(ip)
 #else
-#define	XFS_IFORK_DSIZE(ip)		XFS_CFORK_DSIZE(&ip->i_d, ip->i_mount)
+#define XFS_IFORK_DSIZE(ip)		XFS_CFORK_DSIZE(&ip->i_d, ip->i_mount)
 #endif
 #if XFS_WANT_FUNCS || (XFS_WANT_SPACE && XFSSO_XFS_IFORK_ASIZE)
 int xfs_ifork_asize(xfs_inode_t *ip);
-#define	XFS_IFORK_ASIZE(ip)		xfs_ifork_asize(ip)
+#define XFS_IFORK_ASIZE(ip)		xfs_ifork_asize(ip)
 #else
-#define	XFS_IFORK_ASIZE(ip)		XFS_CFORK_ASIZE(&ip->i_d, ip->i_mount)
+#define XFS_IFORK_ASIZE(ip)		XFS_CFORK_ASIZE(&ip->i_d, ip->i_mount)
 #endif
 #if XFS_WANT_FUNCS || (XFS_WANT_SPACE && XFSSO_XFS_IFORK_SIZE)
 int xfs_ifork_size(xfs_inode_t *ip, int w);
-#define	XFS_IFORK_SIZE(ip,w)		xfs_ifork_size(ip,w)
+#define XFS_IFORK_SIZE(ip,w)		xfs_ifork_size(ip,w)
 #else
-#define	XFS_IFORK_SIZE(ip,w)		XFS_CFORK_SIZE(&ip->i_d, ip->i_mount, w)
+#define XFS_IFORK_SIZE(ip,w)		XFS_CFORK_SIZE(&ip->i_d, ip->i_mount, w)
 #endif
 #if XFS_WANT_FUNCS || (XFS_WANT_SPACE && XFSSO_XFS_IFORK_FORMAT)
 int xfs_ifork_format(xfs_inode_t *ip, int w);
-#define	XFS_IFORK_FORMAT(ip,w)		xfs_ifork_format(ip,w)
+#define XFS_IFORK_FORMAT(ip,w)		xfs_ifork_format(ip,w)
 #else
-#define	XFS_IFORK_FORMAT(ip,w)		XFS_CFORK_FORMAT(&ip->i_d, w)
+#define XFS_IFORK_FORMAT(ip,w)		XFS_CFORK_FORMAT(&ip->i_d, w)
 #endif
 #if XFS_WANT_FUNCS || (XFS_WANT_SPACE && XFSSO_XFS_IFORK_FMT_SET)
 void xfs_ifork_fmt_set(xfs_inode_t *ip, int w, int n);
-#define	XFS_IFORK_FMT_SET(ip,w,n)	xfs_ifork_fmt_set(ip,w,n)
+#define XFS_IFORK_FMT_SET(ip,w,n)	xfs_ifork_fmt_set(ip,w,n)
 #else
-#define	XFS_IFORK_FMT_SET(ip,w,n)	XFS_CFORK_FMT_SET(&ip->i_d, w, n)
+#define XFS_IFORK_FMT_SET(ip,w,n)	XFS_CFORK_FMT_SET(&ip->i_d, w, n)
 #endif
 #if XFS_WANT_FUNCS || (XFS_WANT_SPACE && XFSSO_XFS_IFORK_NEXTENTS)
 int xfs_ifork_nextents(xfs_inode_t *ip, int w);
-#define	XFS_IFORK_NEXTENTS(ip,w)	xfs_ifork_nextents(ip,w)
+#define XFS_IFORK_NEXTENTS(ip,w)	xfs_ifork_nextents(ip,w)
 #else
-#define	XFS_IFORK_NEXTENTS(ip,w)	XFS_CFORK_NEXTENTS(&ip->i_d, w)
+#define XFS_IFORK_NEXTENTS(ip,w)	XFS_CFORK_NEXTENTS(&ip->i_d, w)
 #endif
 #if XFS_WANT_FUNCS || (XFS_WANT_SPACE && XFSSO_XFS_IFORK_NEXT_SET)
 void xfs_ifork_next_set(xfs_inode_t *ip, int w, int n);
-#define	XFS_IFORK_NEXT_SET(ip,w,n)	xfs_ifork_next_set(ip,w,n)
+#define XFS_IFORK_NEXT_SET(ip,w,n)	xfs_ifork_next_set(ip,w,n)
 #else
-#define	XFS_IFORK_NEXT_SET(ip,w,n)	XFS_CFORK_NEXT_SET(&ip->i_d, w, n)
+#define XFS_IFORK_NEXT_SET(ip,w,n)	XFS_CFORK_NEXT_SET(&ip->i_d, w, n)
 #endif
 
 
@@ -386,25 +365,25 @@ void xfs_ifork_next_set(xfs_inode_t *ip, int w, int n);
 /*
  * In-core inode flags.
  */
-#define XFS_IGRIO	0x0001  /* inode used for guaranteed rate i/o */
-#define XFS_IUIOSZ	0x0002  /* inode i/o sizes have been explicitly set */
-#define XFS_IQUIESCE    0x0004  /* we have started quiescing for this inode */
-#define XFS_IRECLAIM    0x0008  /* we have started reclaiming this inode    */
+#define XFS_IGRIO	0x0001	/* inode used for guaranteed rate i/o */
+#define XFS_IUIOSZ	0x0002	/* inode i/o sizes have been explicitly set */
+#define XFS_IQUIESCE	0x0004	/* we have started quiescing for this inode */
+#define XFS_IRECLAIM	0x0008	/* we have started reclaiming this inode    */
 
 /*
  * Flags for inode locking.
  */
-#define	XFS_IOLOCK_EXCL		0x001
-#define	XFS_IOLOCK_SHARED	0x002
-#define	XFS_ILOCK_EXCL		0x004
-#define	XFS_ILOCK_SHARED	0x008
-#define	XFS_IUNLOCK_NONOTIFY	0x010
+#define XFS_IOLOCK_EXCL		0x001
+#define XFS_IOLOCK_SHARED	0x002
+#define XFS_ILOCK_EXCL		0x004
+#define XFS_ILOCK_SHARED	0x008
+#define XFS_IUNLOCK_NONOTIFY	0x010
 #define XFS_EXTENT_TOKEN_RD	0x040
 #define XFS_SIZE_TOKEN_RD	0x080
 #define XFS_EXTSIZE_RD		(XFS_EXTENT_TOKEN_RD|XFS_SIZE_TOKEN_RD)
 #define XFS_WILLLEND		0x100	/* Always acquire tokens for lending */
 #define XFS_EXTENT_TOKEN_WR	(XFS_EXTENT_TOKEN_RD | XFS_WILLLEND)
-#define XFS_SIZE_TOKEN_WR       (XFS_SIZE_TOKEN_RD | XFS_WILLLEND)
+#define XFS_SIZE_TOKEN_WR	(XFS_SIZE_TOKEN_RD | XFS_WILLLEND)
 #define XFS_EXTSIZE_WR		(XFS_EXTSIZE_RD | XFS_WILLLEND)
 
 
@@ -416,58 +395,51 @@ void xfs_ifork_next_set(xfs_inode_t *ip, int w, int n);
 /*
  * Flags for xfs_iflush()
  */
-#define	XFS_IFLUSH_DELWRI_ELSE_SYNC	1
-#define	XFS_IFLUSH_DELWRI_ELSE_ASYNC	2
-#define	XFS_IFLUSH_SYNC			3
-#define	XFS_IFLUSH_ASYNC		4
-#define	XFS_IFLUSH_DELWRI		5
+#define XFS_IFLUSH_DELWRI_ELSE_SYNC	1
+#define XFS_IFLUSH_DELWRI_ELSE_ASYNC	2
+#define XFS_IFLUSH_SYNC			3
+#define XFS_IFLUSH_ASYNC		4
+#define XFS_IFLUSH_DELWRI		5
 
 /*
  * Flags for xfs_iflush_all.
  */
-#define	XFS_FLUSH_ALL		0x1
+#define XFS_FLUSH_ALL		0x1
 
 /*
  * Flags for xfs_itruncate_start().
  */
-#define	XFS_ITRUNC_DEFINITE	0x1
-#define	XFS_ITRUNC_MAYBE	0x2
+#define XFS_ITRUNC_DEFINITE	0x1
+#define XFS_ITRUNC_MAYBE	0x2
 
 /*
- * if XFS_BIG_FILES, 2^(31+PAGE_SHIFT) - 1 (due to linux page cache),
- * else 2^40 - 1 (40=31+9) (might be an int holding a block #)
- * For the not XFS_BIG_FILES case, the value could be 1 higher but we don't
- * do that, for symmetry.
+ * max file offset is 2^(31+PAGE_SHIFT) - 1 (due to linux page cache)
  *
  * NOTE: XFS itself can handle 2^63 - 1 (largest positive value of xfs_fsize_t)
  * but Linux can't go above 2^(31+PAGE_SHIFT)-1: the Linux VM uses a 32 bit
- * signed variable to index cache data, so 2^31 * PAGE_SIZE is as big as 
+ * signed variable to index cache data, so 2^31 * PAGE_SIZE is as big as
  * you can go.
  */
-#if XFS_BIG_FILES
 #define XFS_MAX_FILE_OFFSET	((long long)((1ULL<<(31+PAGE_SHIFT))-1ULL))
-#else
-#define	XFS_MAX_FILE_OFFSET	((1LL<<40)-1LL)
-#endif
 
 #if XFS_WANT_FUNCS || (XFS_WANT_SPACE && XFSSO_XFS_ITOV)
 struct vnode *xfs_itov(xfs_inode_t *ip);
-#define	XFS_ITOV(ip)		xfs_itov(ip)
+#define XFS_ITOV(ip)		xfs_itov(ip)
 #else
-#define	XFS_ITOV(ip)		BHV_TO_VNODE(XFS_ITOBHV(ip))
+#define XFS_ITOV(ip)		BHV_TO_VNODE(XFS_ITOBHV(ip))
 #endif
-#define	XFS_ITOV_NULL(ip)	BHV_TO_VNODE_NULL(XFS_ITOBHV(ip))
+#define XFS_ITOV_NULL(ip)	BHV_TO_VNODE_NULL(XFS_ITOBHV(ip))
 #if XFS_WANT_FUNCS || (XFS_WANT_SPACE && XFSSO_XFS_ITOBHV)
 struct bhv_desc *xfs_itobhv(xfs_inode_t *ip);
-#define	XFS_ITOBHV(ip)		xfs_itobhv(ip)
+#define XFS_ITOBHV(ip)		xfs_itobhv(ip)
 #else
-#define	XFS_ITOBHV(ip)		((struct bhv_desc *)(&((ip)->i_bhv_desc)))
+#define XFS_ITOBHV(ip)		((struct bhv_desc *)(&((ip)->i_bhv_desc)))
 #endif
 #if XFS_WANT_FUNCS || (XFS_WANT_SPACE && XFSSO_XFS_BHVTOI)
 xfs_inode_t *xfs_bhvtoi(struct bhv_desc *bhvp);
-#define	XFS_BHVTOI(bhvp)	xfs_bhvtoi(bhvp)
+#define XFS_BHVTOI(bhvp)	xfs_bhvtoi(bhvp)
 #else
-#define	XFS_BHVTOI(bhvp)	\
+#define XFS_BHVTOI(bhvp)	\
 	((xfs_inode_t *)((char *)(bhvp) - \
 			 (char *)&(((xfs_inode_t *)0)->i_bhv_desc)))
 #endif
@@ -497,11 +469,11 @@ void		xfs_chash_init(struct xfs_mount *);
 void		xfs_chash_free(struct xfs_mount *);
 xfs_inode_t	*xfs_inode_incore(struct xfs_mount *, xfs_ino_t,
 				  struct xfs_trans *);
-void            xfs_inode_lock_init(xfs_inode_t *, struct vnode *);
+void		xfs_inode_lock_init(xfs_inode_t *, struct vnode *);
 int		xfs_iget(struct xfs_mount *, struct xfs_trans *, xfs_ino_t,
 			 uint, xfs_inode_t **, xfs_daddr_t);
-int		xfs_vn_iget(vfs_t *, struct vnode *, xfs_ino_t);
 void		xfs_iput(xfs_inode_t *, uint);
+void		xfs_iput_new(xfs_inode_t *, uint);
 void		xfs_ilock(xfs_inode_t *, uint);
 int		xfs_ilock_nowait(xfs_inode_t *, uint);
 void		xfs_iunlock(xfs_inode_t *, uint);
@@ -526,7 +498,7 @@ int		xfs_iread(struct xfs_mount *, struct xfs_trans *, xfs_ino_t,
 			  xfs_inode_t **, xfs_daddr_t);
 int		xfs_iread_extents(struct xfs_trans *, xfs_inode_t *, int);
 int		xfs_ialloc(struct xfs_trans *, xfs_inode_t *, mode_t, nlink_t,
-		           dev_t, struct cred *, xfs_prid_t, int,
+			   xfs_dev_t, struct cred *, xfs_prid_t, int,
 			   struct xfs_buf **, boolean_t *, xfs_inode_t **);
 void		xfs_xlate_dinode_core(xfs_caddr_t, struct xfs_dinode_core *, int,
 			   xfs_arch_t);
@@ -551,17 +523,16 @@ void		xfs_iunpin(xfs_inode_t *);
 int		xfs_iextents_copy(xfs_inode_t *, xfs_bmbt_rec_32_t *, int);
 int		xfs_iflush(xfs_inode_t *, uint);
 int		xfs_iflush_all(struct xfs_mount *, int);
-int             xfs_ibusy_check(xfs_inode_t *, int);
+int		xfs_ibusy_check(xfs_inode_t *, int);
 int		xfs_iaccess(xfs_inode_t *, mode_t, cred_t *);
 uint		xfs_iroundup(uint);
 void		xfs_ichgtime(xfs_inode_t *, int);
 xfs_fsize_t	xfs_file_last_byte(xfs_inode_t *);
-xfs_inode_t	*xfs_get_inode(dev_t, xfs_ino_t);
 void		xfs_lock_inodes(xfs_inode_t **, int, int, uint);
 
 #define xfs_ipincount(ip)	((unsigned int) atomic_read(&ip->i_pincount))
 
-
+void xfs_revalidate_inode(struct xfs_mount *, vnode_t *vp, xfs_inode_t *);
 
 #ifdef DEBUG
 void		xfs_isize_check(struct xfs_mount *, xfs_inode_t *, xfs_fsize_t);
@@ -572,18 +543,18 @@ void		xfs_isize_check(struct xfs_mount *, xfs_inode_t *, xfs_fsize_t);
 #if defined(DEBUG)
 void		xfs_inobp_check(struct xfs_mount *, struct xfs_buf *);
 #else
-#define	xfs_inobp_check(mp, bp)
+#define xfs_inobp_check(mp, bp)
 #endif /* DEBUG */
 
-extern struct xfs_zone	*xfs_chashlist_zone;
-extern struct xfs_zone	*xfs_ifork_zone;
-extern struct xfs_zone	*xfs_inode_zone;
-extern struct xfs_zone	*xfs_ili_zone;
+extern struct kmem_zone	*xfs_chashlist_zone;
+extern struct kmem_zone	*xfs_ifork_zone;
+extern struct kmem_zone	*xfs_inode_zone;
+extern struct kmem_zone	*xfs_ili_zone;
 extern struct vnodeops	xfs_vnodeops;
 
 #ifdef XFS_ILOCK_TRACE
 #define XFS_ILOCK_KTRACE_SIZE	32
-void	xfs_ilock_trace(xfs_inode_t *ip, int lock, unsigned int lockflags, 
+void	xfs_ilock_trace(xfs_inode_t *ip, int lock, unsigned int lockflags,
 			inst_t *ra);
 #endif
 
