@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2000-2002 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -11,7 +11,7 @@
  *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
- * or the like.  Any license provided herein, whether implied or
+ * or the like.	 Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
@@ -81,7 +81,7 @@ check_ismounted(char *name, char *block)
  * Checks whether a given device has a mounted, writable
  * filesystem, returns 1 if it does & fatal (just warns
  * if not fatal, but allows us to proceed).
- * 
+ *
  * Useful to tools which will produce uncertain results
  * if the filesystem is active - repair, check, logprint.
  */
@@ -177,7 +177,7 @@ findsize(char *path)
 }
 
 
-/* libxfs_device_to_fd: 
+/* libxfs_device_to_fd:
  *     lookup a device number in the device map
  *     return the associated fd
  */
@@ -185,12 +185,12 @@ int
 libxfs_device_to_fd(dev_t device)
 {
 	int d;
-	
+
 	for (d=0;d<MAX_DEVS;d++)
-		if (dev_map[d].dev == device) 
+		if (dev_map[d].dev == device)
 			return dev_map[d].fd;
-	
-	fprintf(stderr, "%s: device_to_fd: device %lld is not open\n", 
+
+	fprintf(stderr, "%s: device_to_fd: device %lld is not open\n",
 		progname, (long long)device);
 	exit(1);
 }
@@ -204,7 +204,7 @@ libxfs_device_open(char *path, int creat, int readonly, int setblksize)
 	int		fd;
 	dev_t		dev;
 	int		d;
-	struct stat     statb;
+	struct stat	statb;
 
 	if ((fd = open(path,
 			(readonly ? O_RDONLY : O_RDWR) |
@@ -241,20 +241,20 @@ libxfs_device_open(char *path, int creat, int readonly, int setblksize)
 	 * we're not opening a real device, in which case
 	 * choose a new fake device number.
 	 */
-	dev=(statb.st_rdev)?(statb.st_rdev):(nextfakedev--);
+	dev = (statb.st_rdev) ? (statb.st_rdev) : (nextfakedev--);
 
-	for (d=0;d<MAX_DEVS;d++)
+	for (d = 0; d < MAX_DEVS; d++)
 		if (dev_map[d].dev == dev) {
-			fprintf(stderr, "%s: device %lld is already open\n", 
+			fprintf(stderr, "%s: device %lld is already open\n",
 			    progname, (long long)dev);
 			exit(1);
 		}
 
-	for (d=0;d<MAX_DEVS;d++)
+	for (d = 0; d < MAX_DEVS; d++)
 		if (!dev_map[d].dev) {
-			dev_map[d].dev=dev;
-			dev_map[d].fd=fd;
-			
+			dev_map[d].dev = dev;
+			dev_map[d].fd = fd;
+
 			return dev;
 		}
 
@@ -265,19 +265,19 @@ libxfs_device_open(char *path, int creat, int readonly, int setblksize)
 void
 libxfs_device_close(dev_t dev)
 {
-	int     d;
+	int	d;
 
-	for (d=0;d<MAX_DEVS;d++)
+	for (d = 0; d < MAX_DEVS; d++)
 		if (dev_map[d].dev == dev) {
-			int fd;
-			
-			fd=dev_map[d].dev;
-			dev_map[d].dev=dev_map[d].fd=0;
-			
+			int	fd;
+
+			fd = dev_map[d].fd;
+			dev_map[d].dev = dev_map[d].fd = 0;
+
 			fsync(fd);
 			ioctl(fd, BLKFLSBUF, 0);
 			close(fd);
-			
+
 			return;
 		}
 
@@ -427,7 +427,7 @@ voldone:
 		if (dname[0] != '/' && needcd)
 			chdir(curdir);
 		if (a->disfile) {
-			a->ddev= libxfs_device_open(dname, a->dcreat, readonly, 
+			a->ddev= libxfs_device_open(dname, a->dcreat, readonly,
 						    a->setblksize);
 			a->dfd = libxfs_device_to_fd(a->ddev);
 		} else {
@@ -645,6 +645,50 @@ rtmount_inodes(xfs_mount_t *mp)
 	return 0;
 }
 
+/*
+ * Initialize realtime fields in the mount structure.
+ */
+static int
+rtmount_init(
+	xfs_mount_t	*mp)	/* file system mount structure */
+{
+	xfs_buf_t	*bp;	/* buffer for last block of subvolume */
+	xfs_daddr_t	d;	/* address of last block of subvolume */
+	xfs_sb_t	*sbp;	/* filesystem superblock copy in mount */
+
+	sbp = &mp->m_sb;
+	if (sbp->sb_rblocks == 0)
+		return 0;
+	if (mp->m_rtdev == 0) {
+		fprintf(stderr, "%s: filesystem has a realtime subvolume\n",
+			progname);
+		return -1;
+	}
+	mp->m_rsumlevels = sbp->sb_rextslog + 1;
+	mp->m_rsumsize =
+		(uint)sizeof(xfs_suminfo_t) * mp->m_rsumlevels *
+		sbp->sb_rbmblocks;
+	mp->m_rsumsize = roundup(mp->m_rsumsize, sbp->sb_blocksize);
+	mp->m_rbmip = mp->m_rsumip = NULL;
+	/*
+	 * Check that the realtime section is an ok size.
+	 */
+	d = (xfs_daddr_t)XFS_FSB_TO_BB(mp, mp->m_sb.sb_rblocks);
+	if (XFS_BB_TO_FSB(mp, d) != mp->m_sb.sb_rblocks) {
+		fprintf(stderr, "%s: realtime init - %llu != %llu\n", progname,
+			(unsigned long long) XFS_BB_TO_FSB(mp, d),
+			(unsigned long long) mp->m_sb.sb_rblocks);
+		return -1;
+	}
+	bp = libxfs_readbuf(mp->m_rtdev, d - 1, 1, 0);
+	if (bp == NULL) {
+		fprintf(stderr, "%s: realtime size check failed\n", progname);
+		return -1;
+	}
+	libxfs_putbuf(bp);
+	return 0;
+}
+
 #define XFS_MOUNT_32BITINODES	0x1
 /*
  * Mount structure initialization, provides a filled-in xfs_mount_t
@@ -752,8 +796,8 @@ libxfs_mount(
 	}
 
 	/* Initialize realtime fields in the mount structure */
-	if (libxfs_rtmount_init(mp)) {
-		fprintf(stderr, "%s: real-time device init failed\n", progname);
+	if (rtmount_init(mp)) {
+		fprintf(stderr, "%s: realtime device init failed\n", progname);
 		return NULL;
 	}
 
