@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2000-2002 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -187,6 +187,8 @@
 /* memory management */
 #define KM_SLEEP	1
 #define KM_SLEEP_IO	2
+#define kmem_zone		xfs_zone	
+#define kmem_zone_t		xfs_zone_t
 #define kmem_zone_init(a, b)	libxfs_zone_init(a, b)
 #define kmem_zone_alloc(z, f)	libxfs_zone_zalloc(z)
 #define kmem_zone_zalloc(z, f)	libxfs_zone_zalloc(z)
@@ -233,14 +235,14 @@
 typedef __uint32_t uint_t;
 typedef __uint32_t inst_t;	/* an instruction */
 typedef enum { B_FALSE, B_TRUE } boolean_t;
-typedef struct { dev_t dev; } buftarg_t;
+typedef struct { dev_t dev; } xfs_buftarg_t;
 #define STATIC
-#define ATTR_ROOT	1	/* use attrs in root namespace */
+#define ATTR_ROOT	0x0002	/* use attrs in root namespace */
 #define ENOATTR		ENODATA	/* Attribute not found */
 #define EFSCORRUPTED	990	/* Filesystem is corrupted */
 #define ktrace_t	void
 #define m_ddev_targp	m_dev
-#define m_rtdev_targp(m)(&(m)->m_rtdev)
+#define kdev_none(x)	(!(x))
 #define KERN_WARNING
 #define XFS_ERROR(e)	(e)
 #define XFS_TEST_ERROR(expr,a,b,c)	( expr )
@@ -252,13 +254,14 @@ typedef struct { dev_t dev; } buftarg_t;
 #define XFS_MOUNT_NOALIGN		0	/* ignored in userspace */
 #define XFS_MOUNT_32BITINODES		0x1	/* enforce in userspace */
 #define XFS_ILOCK_EXCL			0
+#define down_read(a)			((void) 0)
+#define up_read(a)			((void) 0)
 #define mrlock(a,b,c)			((void) 0)
 #define mraccunlock(a)			((void) 0)
 #define mrunlock(a)			((void) 0)
 #define mraccess(a)			((void) 0)
 #define ismrlocked(a,b)			1
 #define spinlock_init(a,b)		((void) 0)
-#define ovbcopy(from,to,count)		memmove(to,from,count)
 #define __return_address		__builtin_return_address(0)
 #define xfs_btree_reada_bufl(m,fsb,c)	((void) 0)
 #define xfs_btree_reada_bufs(m,fsb,c,x)	((void) 0)
@@ -417,7 +420,7 @@ int  xfs_bmap_extents_to_btree (xfs_trans_t *, xfs_inode_t *, xfs_fsblock_t *,
 			xfs_bmap_free_t *, xfs_btree_cur_t **, int, int *, int);
 void xfs_bmap_delete_exlist (xfs_inode_t *, xfs_extnum_t, xfs_extnum_t, int);
 xfs_filblks_t xfs_bmap_worst_indlen (xfs_inode_t *, xfs_filblks_t);
-int  xfs_bmap_isaeof (xfs_inode_t *, xfs_fileoff_t, int, int *);
+int  xfs_bmap_isaeof (xfs_inode_t *, xfs_fileoff_t, int, char *);
 void xfs_bmap_insert_exlist (xfs_inode_t *, xfs_extnum_t, xfs_extnum_t,
 			xfs_bmbt_irec_t *, int);
 
@@ -458,6 +461,8 @@ int  xfs_alloc_split (xfs_btree_cur_t *, int, xfs_agblock_t *,
 
 /* xfs_da_btree.c */
 xfs_dabuf_t *xfs_da_buf_make (int, xfs_buf_t **, inst_t *);
+void xfs_da_binval (struct xfs_trans *, xfs_dabuf_t *);
+void xfs_da_buf_done (xfs_dabuf_t *);
 int  xfs_da_root_join (xfs_da_state_t *, xfs_da_state_blk_t *);
 int  xfs_da_root_split (xfs_da_state_t *, xfs_da_state_blk_t *,
 			xfs_da_state_blk_t *);
@@ -475,6 +480,21 @@ int  xfs_da_node_toosmall (xfs_da_state_t *, int *);
 uint xfs_da_node_lasthash (xfs_dabuf_t *, int *);
 int  xfs_da_do_buf (xfs_trans_t *, xfs_inode_t *, xfs_dablk_t, xfs_daddr_t *,
 			xfs_dabuf_t **, int, int, inst_t *);
+int  xfs_da_split (xfs_da_state_t *);
+int  xfs_da_node_create (xfs_da_args_t *, xfs_dablk_t, int,
+			xfs_dabuf_t **, int);
+int  xfs_da_join (xfs_da_state_t *);
+void xfs_da_fixhashpath (xfs_da_state_t *, xfs_da_state_path_t *);
+int  xfs_da_node_lookup_int (xfs_da_state_t *, int *);
+int  xfs_da_path_shift (xfs_da_state_t *, xfs_da_state_path_t *,
+			int, int, int *);
+int  xfs_da_blk_unlink (xfs_da_state_t *, xfs_da_state_blk_t *,
+			xfs_da_state_blk_t *);
+int  xfs_da_blk_link (xfs_da_state_t *, xfs_da_state_blk_t *,
+			xfs_da_state_blk_t *);
+xfs_da_state_t *xfs_da_state_alloc (void);
+void xfs_da_state_free (xfs_da_state_t *);
+void xfs_da_state_kill_altpath (xfs_da_state_t *);
 
 /* xfs_dir.c */
 int  xfs_dir_node_addname (xfs_da_args_t *);
@@ -538,9 +558,9 @@ void xfs_trans_free_item (xfs_trans_t *, xfs_log_item_desc_t *);
 void xfs_trans_free_items (xfs_trans_t *, int);
 
 /* xfs_trans_buf.c */
-xfs_buf_t *xfs_trans_buf_item_match (xfs_trans_t *, buftarg_t *,
+xfs_buf_t *xfs_trans_buf_item_match (xfs_trans_t *, xfs_buftarg_t *,
 			xfs_daddr_t, int);
-xfs_buf_t *xfs_trans_buf_item_match_all (xfs_trans_t *, buftarg_t *,
+xfs_buf_t *xfs_trans_buf_item_match_all (xfs_trans_t *, xfs_buftarg_t *,
 			xfs_daddr_t, int);
 
 /* xfs_inode_item.c */
