@@ -1,32 +1,32 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ * Copyright (c) 2000-2002 Silicon Graphics, Inc.  All Rights Reserved.
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
- * or the like.  Any license provided herein, whether implied or
+ * or the like.	 Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
@@ -81,7 +81,7 @@ xfs_ialloc_log_di(
 		offsetof(xfs_dinode_t, di_a),
 		sizeof(xfs_dinode_t)
 	};
-        
+
 
 	ASSERT(offsetof(xfs_dinode_t, di_core) == 0);
 	ASSERT((fields & (XFS_DI_U|XFS_DI_A)) == 0);
@@ -114,9 +114,9 @@ xfs_ialloc_ag_alloc(
 	int		*alloc)
 {
 	xfs_agi_t	*agi;		/* allocation group header */
-	xfs_alloc_arg_t	args;		/* allocation argument structure */
+	xfs_alloc_arg_t args;		/* allocation argument structure */
 	int		blks_per_cluster;  /* fs blocks per inode cluster */
-	xfs_btree_cur_t	*cur;		/* inode btree cursor */
+	xfs_btree_cur_t *cur;		/* inode btree cursor */
 	xfs_daddr_t	d;		/* disk addr of buffer */
 	int		error;
 	xfs_buf_t	*fbuf;		/* new free inodes' buffer */
@@ -132,9 +132,9 @@ xfs_ialloc_ag_alloc(
 	static xfs_timestamp_t ztime;	/* zero xfs timestamp */
 	int		isaligned;	/* inode allocation at stripe unit */
 					/* boundary */
-        xfs_dinode_core_t dic;          /* a dinode_core to copy to new */
-                                        /* inodes */
-        
+	xfs_dinode_core_t dic;		/* a dinode_core to copy to new */
+					/* inodes */
+
 	args.tp = tp;
 	args.mp = tp->t_mountp;
 
@@ -151,7 +151,7 @@ xfs_ialloc_ag_alloc(
 	 * Set the alignment for the allocation.
 	 * If stripe alignment is turned on then align at stripe unit
 	 * boundary.
-	 * If the cluster size is smaller than a filesystem block 
+	 * If the cluster size is smaller than a filesystem block
 	 * then we're doing I/O for inodes in filesystem block size pieces,
 	 * so don't need alignment anyway.
 	 */
@@ -161,7 +161,7 @@ xfs_ialloc_ag_alloc(
 		args.alignment = args.mp->m_dalign;
 		isaligned = 1;
 	} else if (XFS_SB_VERSION_HASALIGN(&args.mp->m_sb) &&
-	    args.mp->m_sb.sb_inoalignmt >= 
+	    args.mp->m_sb.sb_inoalignmt >=
 	    XFS_B_TO_FSBT(args.mp, XFS_INODE_CLUSTER_SIZE(args.mp)))
 		args.alignment = args.mp->m_sb.sb_inoalignmt;
 	else
@@ -179,7 +179,7 @@ xfs_ialloc_ag_alloc(
 	 * Allocate a fixed-size extent of inodes.
 	 */
 	args.type = XFS_ALLOCTYPE_NEAR_BNO;
-	args.mod = args.total = args.wasdel = args.isfl = args.userdata = 
+	args.mod = args.total = args.wasdel = args.isfl = args.userdata =
 		args.minalignslop = 0;
 	args.prod = 1;
 	/*
@@ -199,15 +199,15 @@ xfs_ialloc_ag_alloc(
 		args.fsbno = XFS_AGB_TO_FSB(args.mp,
 				INT_GET(agi->agi_seqno, ARCH_CONVERT), args.agbno);
 		if (XFS_SB_VERSION_HASALIGN(&args.mp->m_sb) &&
-	    		args.mp->m_sb.sb_inoalignmt >= 
-	    		XFS_B_TO_FSBT(args.mp, XFS_INODE_CLUSTER_SIZE(args.mp)))
+			args.mp->m_sb.sb_inoalignmt >=
+			XFS_B_TO_FSBT(args.mp, XFS_INODE_CLUSTER_SIZE(args.mp)))
 				args.alignment = args.mp->m_sb.sb_inoalignmt;
 		else
 			args.alignment = 1;
 		if ((error = xfs_alloc_vextent(&args)))
-       		         return error;
+			 return error;
 	}
-	
+
 	if (args.fsbno == NULLFSBLOCK) {
 		*alloc = 0;
 		return 0;
@@ -228,7 +228,7 @@ xfs_ialloc_ag_alloc(
 		ninodes = args.mp->m_sb.sb_inopblock;
 	} else {
 		blks_per_cluster = XFS_INODE_CLUSTER_SIZE(args.mp) /
-			           args.mp->m_sb.sb_blocksize;
+				   args.mp->m_sb.sb_blocksize;
 		nbufs = (int)args.len / blks_per_cluster;
 		ninodes = blks_per_cluster * args.mp->m_sb.sb_inopblock;
 	}
@@ -253,7 +253,7 @@ xfs_ialloc_ag_alloc(
 					 args.mp->m_bsize * blks_per_cluster,
 					 XFS_BUF_LOCK);
 		ASSERT(fbuf);
-		ASSERT(!XFS_BUF_GETERROR(fbuf));		
+		ASSERT(!XFS_BUF_GETERROR(fbuf));
 		/*
 		 * Loop over the inodes in this buffer.
 		 */
@@ -266,16 +266,16 @@ xfs_ialloc_ag_alloc(
 		INT_ZERO(dic.di_gid, ARCH_CONVERT);
 		INT_ZERO(dic.di_nlink, ARCH_CONVERT);
 		INT_ZERO(dic.di_projid, ARCH_CONVERT);
-		bzero(&(dic.di_pad[0]),sizeof(dic.di_pad));
+		memset(&(dic.di_pad[0]), 0, sizeof(dic.di_pad));
 		INT_SET(dic.di_atime.t_sec, ARCH_CONVERT, ztime.t_sec);
 		INT_SET(dic.di_atime.t_nsec, ARCH_CONVERT, ztime.t_nsec);
-                
+
 		INT_SET(dic.di_mtime.t_sec, ARCH_CONVERT, ztime.t_sec);
 		INT_SET(dic.di_mtime.t_nsec, ARCH_CONVERT, ztime.t_nsec);
-                
+
 		INT_SET(dic.di_ctime.t_sec, ARCH_CONVERT, ztime.t_sec);
 		INT_SET(dic.di_ctime.t_nsec, ARCH_CONVERT, ztime.t_nsec);
-                
+
 		INT_ZERO(dic.di_size, ARCH_CONVERT);
 		INT_ZERO(dic.di_nblocks, ARCH_CONVERT);
 		INT_ZERO(dic.di_extsize, ARCH_CONVERT);
@@ -287,11 +287,11 @@ xfs_ialloc_ag_alloc(
 		INT_ZERO(dic.di_dmstate, ARCH_CONVERT);
 		INT_ZERO(dic.di_flags, ARCH_CONVERT);
 		INT_ZERO(dic.di_gen, ARCH_CONVERT);
-                
+
 		for (i = 0; i < ninodes; i++) {
 			free = XFS_MAKE_IPTR(args.mp, fbuf, i);
-                        bcopy (&dic, &(free->di_core), sizeof(xfs_dinode_core_t));
-		        INT_SET(free->di_next_unlinked, ARCH_CONVERT, NULLAGINO);
+			memcpy(&(free->di_core), &dic, sizeof(xfs_dinode_core_t));
+			INT_SET(free->di_next_unlinked, ARCH_CONVERT, NULLAGINO);
 			xfs_ialloc_log_di(tp, fbuf, i,
 				XFS_DI_CORE_BITS | XFS_DI_NEXT_UNLINKED);
 		}
@@ -299,9 +299,9 @@ xfs_ialloc_ag_alloc(
 	}
 	INT_MOD(agi->agi_count, ARCH_CONVERT, newlen);
 	INT_MOD(agi->agi_freecount, ARCH_CONVERT, newlen);
-	mraccess(&args.mp->m_peraglock);
+	down_read(&args.mp->m_peraglock);
 	args.mp->m_perag[INT_GET(agi->agi_seqno, ARCH_CONVERT)].pagi_freecount += newlen;
-	mraccunlock(&args.mp->m_peraglock);
+	up_read(&args.mp->m_peraglock);
 	INT_SET(agi->agi_newino, ARCH_CONVERT, newino);
 	/*
 	 * Insert records describing the new inode chunk into the btree.
@@ -341,7 +341,7 @@ xfs_ialloc_ag_alloc(
 
 /*
  * Select an allocation group to look for a free inode in, based on the parent
- * inode and then mode.  Return the allocation group buffer.
+ * inode and then mode.	 Return the allocation group buffer.
  */
 STATIC xfs_buf_t *			/* allocation group buffer */
 xfs_ialloc_ag_select(
@@ -370,25 +370,27 @@ xfs_ialloc_ag_select(
 	agcount = mp->m_maxagi;
 	if (S_ISDIR(mode))
 		pagno = atomicIncWithWrap((int *)&mp->m_agirotor, agcount);
-	else
+	else {
 		pagno = XFS_INO_TO_AGNO(mp, parent);
+		if (pagno >= agcount)
+			pagno = 0;
+	}
 	ASSERT(pagno < agcount);
 	/*
 	 * Loop through allocation groups, looking for one with a little
 	 * free space in it.  Note we don't look for free inodes, exactly.
 	 * Instead, we include whether there is a need to allocate inodes
-	 * to mean that blocks must be allocated for them, 
+	 * to mean that blocks must be allocated for them,
 	 * if none are currently free.
 	 */
 	agno = pagno;
 	flags = XFS_ALLOC_FLAG_TRYLOCK;
+	down_read(&mp->m_peraglock);
 	for (;;) {
-		mraccess(&mp->m_peraglock);
 		pag = &mp->m_perag[agno];
 		if (!pag->pagi_init) {
 			if (xfs_ialloc_read_agi(mp, tp, agno, &agbp)) {
 				agbp = NULL;
-				mraccunlock(&mp->m_peraglock);
 				goto nextag;
 			}
 		} else
@@ -408,7 +410,6 @@ xfs_ialloc_ag_select(
 			if (agbp == NULL &&
 			    xfs_ialloc_read_agi(mp, tp, agno, &agbp)) {
 				agbp = NULL;
-				mraccunlock(&mp->m_peraglock);
 				goto nextag;
 			}
 			(void)xfs_alloc_pagf_init(mp, tp, agno, flags);
@@ -423,36 +424,38 @@ xfs_ialloc_ag_select(
 				if (agbp == NULL &&
 				    xfs_ialloc_read_agi(mp, tp, agno, &agbp)) {
 					agbp = NULL;
-					mraccunlock(&mp->m_peraglock);
 					goto nextag;
 				}
-				mraccunlock(&mp->m_peraglock);
+				up_read(&mp->m_peraglock);
 				return agbp;
 			}
 		}
 unlock_nextag:
-		mraccunlock(&mp->m_peraglock);
 		if (agbp)
 			xfs_trans_brelse(tp, agbp);
-nextag:		
-		/*   
+nextag:
+		/*
 		 * No point in iterating over the rest, if we're shutting
 		 * down.
 		 */
-		if (XFS_FORCED_SHUTDOWN(mp))
+		if (XFS_FORCED_SHUTDOWN(mp)) {
+			up_read(&mp->m_peraglock);
 			return (xfs_buf_t *)0;
+		}
 		agno++;
-		if (agno == agcount)
+		if (agno >= agcount)
 			agno = 0;
 		if (agno == pagno) {
-			if (flags == 0)
+			if (flags == 0) {
+				up_read(&mp->m_peraglock);
 				return (xfs_buf_t *)0;
+			}
 			flags = 0;
 		}
 	}
 }
 
-/* 
+/*
  * Visible inode allocation functions.
  */
 
@@ -464,10 +467,10 @@ nextag:
  * The arguments IO_agbp and alloc_done are defined to work within
  * the constraint of one allocation per transaction.
  * xfs_dialloc() is designed to be called twice if it has to do an
- * allocation to make more free inodes.  On the first call,
+ * allocation to make more free inodes.	 On the first call,
  * IO_agbp should be set to NULL. If an inode is available,
  * i.e., xfs_dialloc() did not need to do an allocation, an inode
- * number is returned.  In this case, IO_agbp would be set to the 
+ * number is returned.	In this case, IO_agbp would be set to the
  * current ag_buf and alloc_done set to false.
  * If an allocation needed to be done, xfs_dialloc would return
  * the current ag_buf in IO_agbp and set alloc_done to true.
@@ -478,7 +481,7 @@ nextag:
  * guaranteed to have a free inode available.
  *
  * Once we successfully pick an inode its number is returned and the
- * on-disk data structures are updated.  The inode itself is not read
+ * on-disk data structures are updated.	 The inode itself is not read
  * in, since doing so would break ordering constraints with xfs_reclaim.
  */
 int
@@ -496,7 +499,7 @@ xfs_dialloc(
 	xfs_buf_t	*agbp;		/* allocation group header's buffer */
 	xfs_agnumber_t	agno;		/* allocation group number */
 	xfs_agi_t	*agi;		/* allocation group header structure */
-	xfs_btree_cur_t	*cur;		/* inode allocation btree cursor */
+	xfs_btree_cur_t *cur;		/* inode allocation btree cursor */
 	int		error;		/* error return value */
 	int		i;		/* result code */
 	int		ialloced;	/* inode allocation status */
@@ -508,10 +511,10 @@ xfs_dialloc(
 	int		offset;		/* index of inode in chunk */
 	xfs_agino_t	pagino;		/* parent's a.g. relative inode # */
 	xfs_agnumber_t	pagno;		/* parent's allocation group number */
-	xfs_inobt_rec_t	rec;		/* inode allocation record */
+	xfs_inobt_rec_t rec;		/* inode allocation record */
 	xfs_agnumber_t	tagno;		/* testing allocation group number */
-	xfs_btree_cur_t	*tcur;		/* temp cursor */
-	xfs_inobt_rec_t	trec;		/* temp inode allocation record */
+	xfs_btree_cur_t *tcur;		/* temp cursor */
+	xfs_inobt_rec_t trec;		/* temp inode allocation record */
 
 
 	if (*IO_agbp == NULL) {
@@ -521,7 +524,7 @@ xfs_dialloc(
 		 */
 		agbp = xfs_ialloc_ag_select(tp, parent, mode, okalloc);
 		/*
-		 * Couldn't find an allocation group satisfying the 
+		 * Couldn't find an allocation group satisfying the
 		 * criteria, give up.
 		 */
 		if (!agbp) {
@@ -532,7 +535,7 @@ xfs_dialloc(
 		ASSERT(INT_GET(agi->agi_magicnum, ARCH_CONVERT) == XFS_AGI_MAGIC);
 	} else {
 		/*
-		 * Continue where we left off before.  In this case, we 
+		 * Continue where we left off before.  In this case, we
 		 * know that the allocation group has free inodes.
 		 */
 		agbp = *IO_agbp;
@@ -565,8 +568,8 @@ xfs_dialloc(
 	 * allocation groups upward, wrapping at the end.
 	 */
 	*alloc_done = B_FALSE;
-	while (INT_GET(agi->agi_freecount, ARCH_CONVERT) == 0) {
-		/* 
+	while (INT_ISZERO(agi->agi_freecount, ARCH_CONVERT)) {
+		/*
 		 * Don't do anything if we're not supposed to allocate
 		 * any blocks, just go on to the next ag.
 		 */
@@ -611,13 +614,13 @@ nextag:
 			*inop = NULLFSINO;
 			return noroom ? ENOSPC : 0;
 		}
-		mraccess(&mp->m_peraglock);
+		down_read(&mp->m_peraglock);
 		if (mp->m_perag[tagno].pagi_inodeok == 0) {
-			mraccunlock(&mp->m_peraglock);
+			up_read(&mp->m_peraglock);
 			goto nextag;
 		}
 		error = xfs_ialloc_read_agi(mp, tp, tagno, &agbp);
-		mraccunlock(&mp->m_peraglock);
+		up_read(&mp->m_peraglock);
 		if (error)
 			goto nextag;
 		agi = XFS_BUF_TO_AGI(agbp);
@@ -706,7 +709,7 @@ nextag:
 					goto error1;
 				XFS_WANT_CORRUPTED_GOTO(i == 1, error1);
 			}
-			/* 
+			/*
 			 * Search right with cur, go forward 1 record.
 			 */
 			if ((error = xfs_inobt_increment(cur, 0, &i)))
@@ -865,9 +868,9 @@ nextag:
 		goto error0;
 	INT_MOD(agi->agi_freecount, ARCH_CONVERT, -1);
 	xfs_ialloc_log_agi(tp, agbp, XFS_AGI_FREECOUNT);
-	mraccess(&mp->m_peraglock);
+	down_read(&mp->m_peraglock);
 	mp->m_perag[tagno].pagi_freecount--;
-	mraccunlock(&mp->m_peraglock);
+	up_read(&mp->m_peraglock);
 #ifdef DEBUG
 	if (cur->bc_nlevels == 1) {
 		int	freecount = 0;
@@ -911,7 +914,7 @@ xfs_dilocate(
 	xfs_fsblock_t	*bno,	/* output: block containing inode */
 	int		*len,	/* output: num blocks in inode cluster */
 	int		*off,	/* output: index in block of inode */
-	uint		flags)	/* flags concerning inode lookup */	     
+	uint		flags)	/* flags concerning inode lookup */
 {
 	xfs_agblock_t	agbno;	/* block number of inode in the alloc group */
 	xfs_buf_t	*agbp;	/* agi buffer */
@@ -923,10 +926,10 @@ xfs_dilocate(
 	__int32_t	chunk_cnt;	/* count of free inodes in chunk */
 	xfs_inofree_t	chunk_free;	/* mask of free inodes in chunk */
 	xfs_agblock_t	cluster_agbno;	/* first block in inode cluster */
-	xfs_btree_cur_t	*cur;	/* inode btree cursor */
+	xfs_btree_cur_t *cur;	/* inode btree cursor */
 	int		error;	/* error code */
 	int		i;	/* temp state */
-	int		offset;	/* index of inode in its buffer */
+	int		offset; /* index of inode in its buffer */
 	int		offset_agbno;	/* blks from chunk start to inode */
 
 	ASSERT(ino != NULLFSINO);
@@ -939,7 +942,7 @@ xfs_dilocate(
 	if (agno >= mp->m_sb.sb_agcount || agbno >= mp->m_sb.sb_agblocks ||
 	    ino != XFS_AGINO_TO_INO(mp, agno, agino)) {
 #ifdef DEBUG
-	    	if (agno >= mp->m_sb.sb_agcount) {
+		if (agno >= mp->m_sb.sb_agcount) {
 			xfs_fs_cmn_err(CE_ALERT, mp,
 					"xfs_dilocate: agno (%d) >= "
 					"mp->m_sb.sb_agcount (%d)",
@@ -985,9 +988,9 @@ xfs_dilocate(
 		offset_agbno = agbno & mp->m_inoalign_mask;
 		chunk_agbno = agbno - offset_agbno;
 	} else {
-		mraccess(&mp->m_peraglock);
+		down_read(&mp->m_peraglock);
 		error = xfs_ialloc_read_agi(mp, tp, agno, &agbp);
-		mraccunlock(&mp->m_peraglock);
+		up_read(&mp->m_peraglock);
 		if (error) {
 #ifdef DEBUG
 			xfs_fs_cmn_err(CE_ALERT, mp, "xfs_dilocate: "
@@ -1022,7 +1025,7 @@ xfs_dilocate(
 			error = XFS_ERROR(EINVAL);
 		}
 		xfs_trans_brelse(tp, agbp);
-		xfs_btree_del_cursor(cur, XFS_BTREE_NOERROR);		
+		xfs_btree_del_cursor(cur, XFS_BTREE_NOERROR);
 		if (error)
 			return error;
 		chunk_agbno = XFS_AGINO_TO_AGBNO(mp, chunk_agino);
@@ -1166,7 +1169,7 @@ xfs_ialloc_read_agi(
 	}
 #ifdef DEBUG
 	for (i = 0; i < XFS_AGI_UNLINKED_BUCKETS; i++)
-		ASSERT(INT_GET(agi->agi_unlinked[i], ARCH_CONVERT) != 0);
+		ASSERT(!INT_ISZERO(agi->agi_unlinked[i], ARCH_CONVERT));
 #endif
 	XFS_BUF_SET_VTYPE_REF(bp, B_FS_AGI, XFS_AGI_REF);
 	*bpp = bp;
