@@ -1,32 +1,32 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ * Copyright (c) 2000-2002 Silicon Graphics, Inc.  All Rights Reserved.
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
- * or the like.  Any license provided herein, whether implied or
+ * or the like.	 Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
@@ -52,7 +52,7 @@ xfs_inobp_check(
 					i * mp->m_sb.sb_inodesize);
 		if (INT_ISZERO(dip->di_next_unlinked, ARCH_CONVERT))  {
 			xfs_fs_cmn_err(CE_ALERT, mp,
-				"Detected a bogus zero next_unlinked field in incore inode buffer 0x%p.  About to pop an ASSERT.",
+				"Detected a bogus zero next_unlinked field in incore inode buffer 0x%p.	 About to pop an ASSERT.",
 				bp);
 			ASSERT(!INT_ISZERO(dip->di_next_unlinked, ARCH_CONVERT));
 		}
@@ -75,17 +75,17 @@ xfs_inobp_check(
  * to determine the size and location of the buffer to read from disk.
  * If the inode has already been mapped to its buffer and read in once,
  * then use the mapping information stored in the inode rather than
- * calling xfs_imap().  This allows us to avoid the overhead of looking
+ * calling xfs_imap().	This allows us to avoid the overhead of looking
  * at the inode btree for small block file systems (see xfs_dilocate()).
  * We can tell whether the inode has been mapped in before by comparing
- * its disk block address to 0.  Only uninitialized inodes will have
+ * its disk block address to 0.	 Only uninitialized inodes will have
  * 0 for the disk block address.
  */
 int
 xfs_itobp(
 	xfs_mount_t	*mp,
 	xfs_trans_t	*tp,
-	xfs_inode_t	*ip,	
+	xfs_inode_t	*ip,
 	xfs_dinode_t	**dipp,
 	xfs_buf_t	**bpp,
 	xfs_daddr_t	bno)
@@ -117,6 +117,16 @@ xfs_itobp(
 		 */
 		if ((imap.im_blkno + imap.im_len) >
 		    XFS_FSB_TO_BB(mp, mp->m_sb.sb_dblocks)) {
+#ifdef DEBUG
+			xfs_fs_cmn_err(CE_ALERT, mp, "xfs_itobp: "
+					"(imap.im_blkno (0x%llx) "
+					"+ imap.im_len (0x%llx)) > "
+					" XFS_FSB_TO_BB(mp, "
+					"mp->m_sb.sb_dblocks) (0x%llx)",
+					(unsigned long long) imap.im_blkno,
+					(unsigned long long) imap.im_len,
+					XFS_FSB_TO_BB(mp, mp->m_sb.sb_dblocks));
+#endif /* DEBUG */
 			return XFS_ERROR(EINVAL);
 		}
 
@@ -139,13 +149,20 @@ xfs_itobp(
 	ASSERT(bno == 0 || bno == imap.im_blkno);
 
 	/*
-	 * Read in the buffer.  If tp is NULL, xfs_trans_read_buf() will
+	 * Read in the buffer.	If tp is NULL, xfs_trans_read_buf() will
 	 * default to just a read_buf() call.
 	 */
 	error = xfs_trans_read_buf(mp, tp, mp->m_ddev_targp, imap.im_blkno,
 				   (int)imap.im_len, XFS_BUF_LOCK, &bp);
 
 	if (error) {
+#ifdef DEBUG
+		xfs_fs_cmn_err(CE_ALERT, mp, "xfs_itobp: "
+				"xfs_trans_read_buf() returned error %d, "
+				"imap.im_blkno 0x%llx, imap.im_len 0x%llx",
+				error, (unsigned long long) imap.im_blkno,
+				(unsigned long long) imap.im_len);
+#endif /* DEBUG */
 		return error;
 	}
 #ifdef __KERNEL__
@@ -169,8 +186,8 @@ xfs_itobp(
 		if (XFS_TEST_ERROR(!di_ok, mp, XFS_ERRTAG_ITOBP_INOTOBP,
 				 XFS_RANDOM_ITOBP_INOTOBP)) {
 #ifdef DEBUG
-			prdev("bad inode magic/vsn daddr 0x%Lx #%d (magic=%x)", 
-				mp->m_dev, imap.im_blkno, i,
+			prdev("bad inode magic/vsn daddr 0x%llx #%d (magic=%x)",
+				mp->m_dev, (unsigned long long)imap.im_blkno, i,
 				INT_GET(dip->di_core.di_magic, ARCH_CONVERT));
 #endif
 			xfs_trans_brelse(tp, bp);
@@ -196,8 +213,8 @@ xfs_itobp(
 
 /*
  * Move inode type and inode format specific information from the
- * on-disk inode to the in-core inode.  For fifos, devs, and sockets
- * this means set if_rdev to the proper value.  For files, directories,
+ * on-disk inode to the in-core inode.	For fifos, devs, and sockets
+ * this means set if_rdev to the proper value.	For files, directories,
  * and symlinks this means to bring in the in-line data or extent
  * pointers.  For a file in B-tree format, only the root is immediately
  * brought in-core.  The rest will be in-lined in if_extents when it
@@ -206,32 +223,36 @@ xfs_itobp(
 STATIC int
 xfs_iformat(
 	xfs_inode_t		*ip,
-	xfs_dinode_t		*dip,
-	int			alloc_mode)
+	xfs_dinode_t		*dip)
 {
 	xfs_attr_shortform_t	*atp;
 	int			size;
 	int			error;
-        xfs_fsize_t             di_size;
+	xfs_fsize_t		di_size;
 	ip->i_df.if_ext_max =
 		XFS_IFORK_DSIZE(ip) / (uint)sizeof(xfs_bmbt_rec_t);
 	error = 0;
 
-	if (INT_GET(dip->di_core.di_nextents, ARCH_CONVERT) + 
-                INT_GET(dip->di_core.di_anextents, ARCH_CONVERT) >
+	if (INT_GET(dip->di_core.di_nextents, ARCH_CONVERT) +
+		INT_GET(dip->di_core.di_anextents, ARCH_CONVERT) >
 	    INT_GET(dip->di_core.di_nblocks, ARCH_CONVERT)) {
 		xfs_fs_cmn_err(CE_WARN, ip->i_mount,
-			"corrupt dinode %Lu, extent total = %d, nblocks = %Ld.  Unmount and run xfs_repair.",
-			ip->i_ino,
-			(int)(INT_GET(dip->di_core.di_nextents, ARCH_CONVERT) + INT_GET(dip->di_core.di_anextents, ARCH_CONVERT)),
+			"corrupt dinode %Lu, extent total = %d, nblocks = %Lu."
+			"  Unmount and run xfs_repair.",
+			(unsigned long long)ip->i_ino,
+			(int)(INT_GET(dip->di_core.di_nextents, ARCH_CONVERT)
+			    + INT_GET(dip->di_core.di_anextents, ARCH_CONVERT)),
+			(unsigned long long)
 			INT_GET(dip->di_core.di_nblocks, ARCH_CONVERT));
 		return XFS_ERROR(EFSCORRUPTED);
 	}
 
 	if (INT_GET(dip->di_core.di_forkoff, ARCH_CONVERT) > ip->i_mount->m_sb.sb_inodesize) {
 		xfs_fs_cmn_err(CE_WARN, ip->i_mount,
-			"corrupt dinode %Lu, forkoff = 0x%x.  Unmount and run xfs_repair.",
-			ip->i_ino, (int)(INT_GET(dip->di_core.di_forkoff, ARCH_CONVERT)));
+			"corrupt dinode %Lu, forkoff = 0x%x."
+			"  Unmount and run xfs_repair.",
+			(unsigned long long)ip->i_ino,
+			(int)(INT_GET(dip->di_core.di_forkoff, ARCH_CONVERT)));
 		return XFS_ERROR(EFSCORRUPTED);
 	}
 
@@ -256,31 +277,33 @@ xfs_iformat(
 			 */
 			if ((INT_GET(dip->di_core.di_mode, ARCH_CONVERT) & IFMT) == IFREG) {
 				xfs_fs_cmn_err(CE_WARN, ip->i_mount,
-					"corrupt inode (local format for regular file) %Lu.  Unmount and run xfs_repair.",
-					ip->i_ino);
+					"corrupt inode "
+					"(local format for regular file) %Lu.  "
+					"Unmount and run xfs_repair.",
+					(unsigned long long) ip->i_ino);
 				return XFS_ERROR(EFSCORRUPTED);
 			}
-                        
-                        di_size=INT_GET(dip->di_core.di_size, ARCH_CONVERT);
+
+			di_size = INT_GET(dip->di_core.di_size, ARCH_CONVERT);
 			if (di_size >
 			    XFS_DFORK_DSIZE_ARCH(dip, ip->i_mount, ARCH_CONVERT)) {
 				xfs_fs_cmn_err(CE_WARN, ip->i_mount,
-					"corrupt inode %Lu (bad size %Ld for local inode).  Unmount and run xfs_repair.",
-					ip->i_ino, di_size);
+					"corrupt inode %Lu "
+					"(bad size %Ld for local inode).  "
+					"Unmount and run xfs_repair.",
+					(unsigned long long) ip->i_ino,
+					(long long) di_size);
 				return XFS_ERROR(EFSCORRUPTED);
 			}
 
 			size = (int)di_size;
-			error = xfs_iformat_local(ip, dip, XFS_DATA_FORK,
-						size, alloc_mode);
+			error = xfs_iformat_local(ip, dip, XFS_DATA_FORK, size);
 			break;
 		case XFS_DINODE_FMT_EXTENTS:
-			error = xfs_iformat_extents(ip, dip, XFS_DATA_FORK,
-						alloc_mode);
+			error = xfs_iformat_extents(ip, dip, XFS_DATA_FORK);
 			break;
 		case XFS_DINODE_FMT_BTREE:
-			error = xfs_iformat_btree(ip, dip, XFS_DATA_FORK,
-						alloc_mode);
+			error = xfs_iformat_btree(ip, dip, XFS_DATA_FORK);
 			break;
 		default:
 			return XFS_ERROR(EFSCORRUPTED);
@@ -292,27 +315,24 @@ xfs_iformat(
 	}
 	if (error) {
 		return error;
-        }
+	}
 	if (!XFS_DFORK_Q_ARCH(dip, ARCH_CONVERT))
 		return 0;
 	ASSERT(ip->i_afp == NULL);
-	ip->i_afp = kmem_zone_zalloc(xfs_ifork_zone, alloc_mode);
+	ip->i_afp = kmem_zone_zalloc(xfs_ifork_zone, KM_SLEEP);
 	ip->i_afp->if_ext_max =
 		XFS_IFORK_ASIZE(ip) / (uint)sizeof(xfs_bmbt_rec_t);
 	switch (INT_GET(dip->di_core.di_aformat, ARCH_CONVERT)) {
 	case XFS_DINODE_FMT_LOCAL:
 		atp = (xfs_attr_shortform_t *)XFS_DFORK_APTR_ARCH(dip, ARCH_CONVERT);
 		size = (int)INT_GET(atp->hdr.totsize, ARCH_CONVERT);
-		error = xfs_iformat_local(ip, dip, XFS_ATTR_FORK, size,
-						alloc_mode);
+		error = xfs_iformat_local(ip, dip, XFS_ATTR_FORK, size);
 		break;
 	case XFS_DINODE_FMT_EXTENTS:
-		error = xfs_iformat_extents(ip, dip, XFS_ATTR_FORK,
-						alloc_mode);
+		error = xfs_iformat_extents(ip, dip, XFS_ATTR_FORK);
 		break;
 	case XFS_DINODE_FMT_BTREE:
-		error = xfs_iformat_btree(ip, dip, XFS_ATTR_FORK,
-						alloc_mode);
+		error = xfs_iformat_btree(ip, dip, XFS_ATTR_FORK);
 		break;
 	default:
 		error = XFS_ERROR(EFSCORRUPTED);
@@ -341,8 +361,7 @@ xfs_iformat_local(
 	xfs_inode_t	*ip,
 	xfs_dinode_t	*dip,
 	int		whichfork,
-	int		size,
-	int		alloc_mode)
+	int		size)
 {
 	xfs_ifork_t	*ifp;
 	int		real_size;
@@ -350,12 +369,14 @@ xfs_iformat_local(
 	/*
 	 * If the size is unreasonable, then something
 	 * is wrong and we just bail out rather than crash in
-	 * kmem_alloc() or bcopy() below.
+	 * kmem_alloc() or memcpy() below.
 	 */
 	if (size > XFS_DFORK_SIZE_ARCH(dip, ip->i_mount, whichfork, ARCH_CONVERT)) {
 		xfs_fs_cmn_err(CE_WARN, ip->i_mount,
-			"corrupt inode %Lu (bad size %d for local fork, size = %d).  Unmount and run xfs_repair.",
-			ip->i_ino, size,
+			"corrupt inode %Lu "
+			"(bad size %d for local fork, size = %d).  "
+			"Unmount and run xfs_repair.",
+			(unsigned long long) ip->i_ino, size,
 			XFS_DFORK_SIZE_ARCH(dip, ip->i_mount, whichfork, ARCH_CONVERT));
 		return XFS_ERROR(EFSCORRUPTED);
 	}
@@ -367,12 +388,13 @@ xfs_iformat_local(
 		ifp->if_u1.if_data = ifp->if_u2.if_inline_data;
 	else {
 		real_size = roundup(size, 4);
-		ifp->if_u1.if_data = kmem_alloc(real_size, alloc_mode);
+		ifp->if_u1.if_data = kmem_alloc(real_size, KM_SLEEP);
 	}
 	ifp->if_bytes = size;
 	ifp->if_real_bytes = real_size;
 	if (size)
-		bcopy(XFS_DFORK_PTR_ARCH(dip, whichfork, ARCH_CONVERT), ifp->if_u1.if_data, size);
+		memcpy(ifp->if_u1.if_data,
+			XFS_DFORK_PTR_ARCH(dip, whichfork, ARCH_CONVERT), size);
 	ifp->if_flags &= ~XFS_IFEXTENTS;
 	ifp->if_flags |= XFS_IFINLINE;
 	return 0;
@@ -391,8 +413,7 @@ STATIC int
 xfs_iformat_extents(
 	xfs_inode_t	*ip,
 	xfs_dinode_t	*dip,
-	int		whichfork,
-	int		alloc_mode)
+	int		whichfork)
 {
 	xfs_ifork_t	*ifp;
 	int		nex;
@@ -406,12 +427,13 @@ xfs_iformat_extents(
 	/*
 	 * If the number of extents is unreasonable, then something
 	 * is wrong and we just bail out rather than crash in
-	 * kmem_alloc() or bcopy() below.
+	 * kmem_alloc() or memcpy() below.
 	 */
 	if (size < 0 || size > XFS_DFORK_SIZE_ARCH(dip, ip->i_mount, whichfork, ARCH_CONVERT)) {
 		xfs_fs_cmn_err(CE_WARN, ip->i_mount,
-			"corrupt inode %Lu ((a)extents = %d).  Unmount and run xfs_repair.",
-			ip->i_ino, nex);
+			"corrupt inode %Lu ((a)extents = %d).  "
+			"Unmount and run xfs_repair.",
+			(unsigned long long) ip->i_ino, nex);
 		return XFS_ERROR(EFSCORRUPTED);
 	}
 
@@ -421,7 +443,7 @@ xfs_iformat_extents(
 	else if (nex <= XFS_INLINE_EXTS)
 		ifp->if_u1.if_extents = ifp->if_u2.if_inline_ext;
 	else {
-		ifp->if_u1.if_extents = kmem_alloc(size, alloc_mode);
+		ifp->if_u1.if_extents = kmem_alloc(size, KM_SLEEP);
 		ASSERT(ifp->if_u1.if_extents != NULL);
 		real_size = size;
 	}
@@ -431,8 +453,8 @@ xfs_iformat_extents(
 		xfs_validate_extents(
 			(xfs_bmbt_rec_32_t *)XFS_DFORK_PTR_ARCH(dip, whichfork, ARCH_CONVERT),
 			nex, XFS_EXTFMT_INODE(ip));
-		bcopy(XFS_DFORK_PTR_ARCH(dip, whichfork, ARCH_CONVERT), ifp->if_u1.if_extents,
-		      size);
+		memcpy(ifp->if_u1.if_extents,
+			XFS_DFORK_PTR_ARCH(dip, whichfork, ARCH_CONVERT), size);
 		xfs_bmap_trace_exlist("xfs_iformat_extents", ip, nex,
 			whichfork);
 		if (whichfork != XFS_DATA_FORK ||
@@ -457,8 +479,7 @@ STATIC int
 xfs_iformat_btree(
 	xfs_inode_t		*ip,
 	xfs_dinode_t		*dip,
-	int			whichfork,
-	int			alloc_mode)
+	int			whichfork)
 {
 	xfs_bmdr_block_t	*dfp;
 	xfs_ifork_t		*ifp;
@@ -483,13 +504,14 @@ xfs_iformat_btree(
 			XFS_DFORK_SIZE_ARCH(dip, ip->i_mount, whichfork, ARCH_CONVERT)
 	    || XFS_IFORK_NEXTENTS(ip, whichfork) > ip->i_d.di_nblocks) {
 		xfs_fs_cmn_err(CE_WARN, ip->i_mount,
-			"corrupt inode %Lu (btree).  Unmount and run xfs_repair.",
-			ip->i_ino);
+			"corrupt inode %Lu (btree).  "
+			"Unmount and run xfs_repair.",
+			(unsigned long long) ip->i_ino);
 		return XFS_ERROR(EFSCORRUPTED);
 	}
 
 	ifp->if_broot_bytes = size;
-	ifp->if_broot = kmem_alloc(size, alloc_mode);
+	ifp->if_broot = kmem_alloc(size, KM_SLEEP);
 	ASSERT(ifp->if_broot != NULL);
 	/*
 	 * Copy and convert from the on-disk structure
@@ -507,79 +529,79 @@ xfs_iformat_btree(
  * xfs_xlate_dinode_core - translate an xfs_inode_core_t between ondisk
  * and native format
  *
- * buf  = on-disk representation 
- * dip  = native representation 
- * dir  = direction - +ve -> disk to native
- *                    -ve -> native to disk
+ * buf	= on-disk representation
+ * dip	= native representation
+ * dir	= direction - +ve -> disk to native
+ *		      -ve -> native to disk
  * arch = on-disk architecture
  */
- 
-void 
-xfs_xlate_dinode_core(xfs_caddr_t buf, xfs_dinode_core_t *dip, 
+
+void
+xfs_xlate_dinode_core(xfs_caddr_t buf, xfs_dinode_core_t *dip,
     int dir, xfs_arch_t arch)
 {
-    xfs_dinode_core_t   *buf_core;
-    xfs_dinode_core_t   *mem_core;
-    
+    xfs_dinode_core_t	*buf_core;
+    xfs_dinode_core_t	*mem_core;
+
     ASSERT(dir);
-    
+
     buf_core=(xfs_dinode_core_t*)buf;
     mem_core=(xfs_dinode_core_t*)dip;
-    
+
     if (arch == ARCH_NOCONVERT) {
-        if (dir>0) {
-            bcopy((xfs_caddr_t)buf_core, (xfs_caddr_t)mem_core, sizeof(xfs_dinode_core_t));
-        } else {
-            bcopy((xfs_caddr_t)mem_core, (xfs_caddr_t)buf_core, sizeof(xfs_dinode_core_t));
-        }
-        return;
+	if (dir>0) {
+	    memcpy((xfs_caddr_t)mem_core, (xfs_caddr_t)buf_core, sizeof(xfs_dinode_core_t));
+	} else {
+	    memcpy((xfs_caddr_t)buf_core, (xfs_caddr_t)mem_core, sizeof(xfs_dinode_core_t));
+	}
+	return;
     }
-    
-    INT_XLATE(buf_core->di_magic,       mem_core->di_magic,        dir, arch);
-    INT_XLATE(buf_core->di_mode,        mem_core->di_mode,         dir, arch);
-    INT_XLATE(buf_core->di_version,     mem_core->di_version,      dir, arch);
-    INT_XLATE(buf_core->di_format,      mem_core->di_format,       dir, arch);
-    INT_XLATE(buf_core->di_onlink,      mem_core->di_onlink,       dir, arch);
-    INT_XLATE(buf_core->di_uid,         mem_core->di_uid,          dir, arch);
-    INT_XLATE(buf_core->di_gid,         mem_core->di_gid,          dir, arch);
-    INT_XLATE(buf_core->di_nlink,       mem_core->di_nlink,        dir, arch);
-    INT_XLATE(buf_core->di_projid,      mem_core->di_projid,       dir, arch);
-    
+
+    INT_XLATE(buf_core->di_magic,	mem_core->di_magic,	   dir, arch);
+    INT_XLATE(buf_core->di_mode,	mem_core->di_mode,	   dir, arch);
+    INT_XLATE(buf_core->di_version,	mem_core->di_version,	   dir, arch);
+    INT_XLATE(buf_core->di_format,	mem_core->di_format,	   dir, arch);
+    INT_XLATE(buf_core->di_onlink,	mem_core->di_onlink,	   dir, arch);
+    INT_XLATE(buf_core->di_uid,		mem_core->di_uid,	   dir, arch);
+    INT_XLATE(buf_core->di_gid,		mem_core->di_gid,	   dir, arch);
+    INT_XLATE(buf_core->di_nlink,	mem_core->di_nlink,	   dir, arch);
+    INT_XLATE(buf_core->di_projid,	mem_core->di_projid,	   dir, arch);
+
     if (dir>0) {
-        bcopy(buf_core->di_pad, mem_core->di_pad, sizeof(buf_core->di_pad));
+	memcpy(mem_core->di_pad, buf_core->di_pad, sizeof(buf_core->di_pad));
     } else {
-        bcopy(mem_core->di_pad, buf_core->di_pad, sizeof(buf_core->di_pad));
+	memcpy(buf_core->di_pad, mem_core->di_pad, sizeof(buf_core->di_pad));
     }
-    
+
     INT_XLATE(buf_core->di_atime.t_sec, mem_core->di_atime.t_sec,  dir, arch);
     INT_XLATE(buf_core->di_atime.t_nsec,mem_core->di_atime.t_nsec, dir, arch);
-    
+
     INT_XLATE(buf_core->di_mtime.t_sec, mem_core->di_mtime.t_sec,  dir, arch);
     INT_XLATE(buf_core->di_mtime.t_nsec,mem_core->di_mtime.t_nsec, dir, arch);
-    
+
     INT_XLATE(buf_core->di_ctime.t_sec, mem_core->di_ctime.t_sec,  dir, arch);
     INT_XLATE(buf_core->di_ctime.t_nsec,mem_core->di_ctime.t_nsec, dir, arch);
-    
-    INT_XLATE(buf_core->di_size,        mem_core->di_size,         dir, arch);
-    INT_XLATE(buf_core->di_nblocks,     mem_core->di_nblocks,      dir, arch);
-    INT_XLATE(buf_core->di_extsize,     mem_core->di_extsize,      dir, arch);
-    
-    INT_XLATE(buf_core->di_nextents,    mem_core->di_nextents,     dir, arch);
-    INT_XLATE(buf_core->di_anextents,   mem_core->di_anextents,    dir, arch);
-    INT_XLATE(buf_core->di_forkoff,     mem_core->di_forkoff,      dir, arch);
-    INT_XLATE(buf_core->di_aformat,     mem_core->di_aformat,      dir, arch);
-    INT_XLATE(buf_core->di_dmevmask,    mem_core->di_dmevmask,     dir, arch);
-    INT_XLATE(buf_core->di_dmstate,     mem_core->di_dmstate,      dir, arch);
-    INT_XLATE(buf_core->di_flags,       mem_core->di_flags,        dir, arch);
-    INT_XLATE(buf_core->di_gen,         mem_core->di_gen,          dir, arch);
-    
+
+    INT_XLATE(buf_core->di_size,	mem_core->di_size,	   dir, arch);
+    INT_XLATE(buf_core->di_nblocks,	mem_core->di_nblocks,	   dir, arch);
+    INT_XLATE(buf_core->di_extsize,	mem_core->di_extsize,	   dir, arch);
+
+    INT_XLATE(buf_core->di_nextents,	mem_core->di_nextents,	   dir, arch);
+    INT_XLATE(buf_core->di_anextents,	mem_core->di_anextents,	   dir, arch);
+    INT_XLATE(buf_core->di_forkoff,	mem_core->di_forkoff,	   dir, arch);
+    INT_XLATE(buf_core->di_aformat,	mem_core->di_aformat,	   dir, arch);
+    INT_XLATE(buf_core->di_dmevmask,	mem_core->di_dmevmask,	   dir, arch);
+    INT_XLATE(buf_core->di_dmstate,	mem_core->di_dmstate,	   dir, arch);
+    INT_XLATE(buf_core->di_flags,	mem_core->di_flags,	   dir, arch);
+    INT_XLATE(buf_core->di_gen,		mem_core->di_gen,	   dir, arch);
+
 }
 
 /*
  * Given a mount structure and an inode number, return a pointer
  * to a newly allocated in-core inode coresponding to the given
  * inode number.
- * 
+ *
  * Initialize the inode's attributes and extent pointers if it
  * already has them (it will not if the inode has no links).
  */
@@ -589,26 +611,24 @@ xfs_iread(
 	xfs_trans_t	*tp,
 	xfs_ino_t	ino,
 	xfs_inode_t	**ipp,
-	xfs_daddr_t		bno)
+	xfs_daddr_t	bno)
 {
 	xfs_buf_t	*bp;
 	xfs_dinode_t	*dip;
 	xfs_inode_t	*ip;
 	int		error;
-	int		alloc_mode = tp ? KM_SLEEP : KM_SLEEP_IO;
 
 	ASSERT(xfs_inode_zone != NULL);
 
-	ip = kmem_zone_zalloc(xfs_inode_zone, alloc_mode);
+	ip = kmem_zone_zalloc(xfs_inode_zone, KM_SLEEP);
 	ip->i_ino = ino;
-	ip->i_dev = mp->m_dev;
 	ip->i_mount = mp;
 
 	/*
 	 * Get pointer's to the on-disk inode and the buffer containing it.
 	 * If the inode number refers to a block outside the file system
 	 * then xfs_itobp() will return NULL.  In this case we should
-	 * return NULL as well.  Set i_blkno to 0 so that xfs_itobp() will
+	 * return NULL as well.	 Set i_blkno to 0 so that xfs_itobp() will
 	 * know that this is a new incore inode.
 	 */
 	error = xfs_itobp(mp, tp, ip, &dip, &bp, bno);
@@ -623,31 +643,38 @@ xfs_iread(
 	 * Do this before xfs_iformat in case it adds entries.
 	 */
 #ifdef XFS_BMAP_TRACE
-	ip->i_xtrace = ktrace_alloc(XFS_BMAP_KTRACE_SIZE, alloc_mode);
+	ip->i_xtrace = ktrace_alloc(XFS_BMAP_KTRACE_SIZE, KM_SLEEP);
 #endif
 #ifdef XFS_BMBT_TRACE
-	ip->i_btrace = ktrace_alloc(XFS_BMBT_KTRACE_SIZE, alloc_mode);
+	ip->i_btrace = ktrace_alloc(XFS_BMBT_KTRACE_SIZE, KM_SLEEP);
 #endif
 #ifdef XFS_RW_TRACE
-	ip->i_rwtrace = ktrace_alloc(XFS_RW_KTRACE_SIZE, alloc_mode);
+	ip->i_rwtrace = ktrace_alloc(XFS_RW_KTRACE_SIZE, KM_SLEEP);
 #endif
 #ifdef XFS_STRAT_TRACE
-	ip->i_strat_trace = ktrace_alloc(XFS_STRAT_KTRACE_SIZE, alloc_mode);
+	ip->i_strat_trace = ktrace_alloc(XFS_STRAT_KTRACE_SIZE, KM_SLEEP);
 #endif
 #ifdef XFS_ILOCK_TRACE
-	ip->i_lock_trace = ktrace_alloc(XFS_ILOCK_KTRACE_SIZE, alloc_mode);
+	ip->i_lock_trace = ktrace_alloc(XFS_ILOCK_KTRACE_SIZE, KM_SLEEP);
 #endif
 #ifdef XFS_DIR2_TRACE
-	ip->i_dir_trace = ktrace_alloc(XFS_DIR2_KTRACE_SIZE, alloc_mode);
+	ip->i_dir_trace = ktrace_alloc(XFS_DIR2_KTRACE_SIZE, KM_SLEEP);
 #endif
 
 	/*
 	 * If we got something that isn't an inode it means someone
 	 * (nfs or dmi) has a stale handle.
 	 */
-        if (INT_GET(dip->di_core.di_magic, ARCH_CONVERT) != XFS_DINODE_MAGIC) {
+	if (INT_GET(dip->di_core.di_magic, ARCH_CONVERT) != XFS_DINODE_MAGIC) {
 		kmem_zone_free(xfs_inode_zone, ip);
 		xfs_trans_brelse(tp, bp);
+#ifdef DEBUG
+		xfs_fs_cmn_err(CE_ALERT, mp, "xfs_iread: "
+				"dip->di_core.di_magic (0x%x) != "
+				"XFS_DINODE_MAGIC (0x%x)",
+				INT_GET(dip->di_core.di_magic, ARCH_CONVERT),
+				XFS_DINODE_MAGIC);
+#endif /* DEBUG */
 		return XFS_ERROR(EINVAL);
 	}
 
@@ -659,12 +686,17 @@ xfs_iread(
 	 * Otherwise, just get the truly permanent information.
 	 */
 	if (!INT_ISZERO(dip->di_core.di_mode, ARCH_CONVERT)) {
-                xfs_xlate_dinode_core((xfs_caddr_t)&dip->di_core, 
-                     &(ip->i_d), 1, ARCH_CONVERT);
-		error = xfs_iformat(ip, dip, alloc_mode);
+		xfs_xlate_dinode_core((xfs_caddr_t)&dip->di_core,
+		     &(ip->i_d), 1, ARCH_CONVERT);
+		error = xfs_iformat(ip, dip);
 		if (error)  {
 			kmem_zone_free(xfs_inode_zone, ip);
 			xfs_trans_brelse(tp, bp);
+#ifdef DEBUG
+			xfs_fs_cmn_err(CE_ALERT, mp, "xfs_iread: "
+					"xfs_iformat() returned error %d",
+					error);
+#endif /* DEBUG */
 			return error;
 		}
 	} else {
@@ -681,19 +713,19 @@ xfs_iread(
 		ip->i_d.di_mode = 0;
 		/*
 		 * Initialize the per-fork minima and maxima for a new
-		 * inode here.  xfs_iformat will do it for old inodes.
+		 * inode here.	xfs_iformat will do it for old inodes.
 		 */
 		ip->i_df.if_ext_max =
 			XFS_IFORK_DSIZE(ip) / (uint)sizeof(xfs_bmbt_rec_t);
-	}	
+	}
 
 	/*
 	 * The inode format changed when we moved the link count and
 	 * made it 32 bits long.  If this is an old format inode,
-	 * convert it in memory to look like a new one.  If it gets
+	 * convert it in memory to look like a new one.	 If it gets
 	 * flushed to disk we will convert back before flushing or
-	 * logging it.  We zero out the new projid field and the old link
-	 * count field.  We'll handle clearing the pad field (the remains
+	 * logging it.	We zero out the new projid field and the old link
+	 * count field.	 We'll handle clearing the pad field (the remains
 	 * of the old uuid field) when we actually convert the inode to
 	 * the new format. We don't change the version number so that we
 	 * can distinguish this from a real new format inode.
@@ -708,7 +740,7 @@ xfs_iread(
 
 	/*
 	 * Mark the buffer containing the inode as something to keep
-	 * around for a while.  This helps to keep recently accessed
+	 * around for a while.	This helps to keep recently accessed
 	 * meta-data in-core longer.
 	 */
 	 XFS_BUF_SET_REF(bp, XFS_INO_REF);
@@ -719,7 +751,7 @@ xfs_iread(
 	 * in xfs_itobp() above.  If tp is NULL, this is just a normal
 	 * brelse().  If we're within a transaction, then xfs_trans_brelse()
 	 * will only release the buffer if it is not dirty within the
-	 * transaction.  It will be OK to release the buffer in this case,
+	 * transaction.	 It will be OK to release the buffer in this case,
 	 * because inodes on disk are never destroyed and we will be
 	 * locking the new in-core inode before putting it in the hash
 	 * table where other processes can find it.  Thus we don't have
@@ -752,7 +784,7 @@ xfs_iread_extents(
 	/*
 	 * We know that the size is legal (it's checked in iformat_btree)
 	 */
-	ifp->if_u1.if_extents = kmem_alloc(size, tp ? KM_SLEEP : KM_SLEEP_IO);
+	ifp->if_u1.if_extents = kmem_alloc(size, KM_SLEEP);
 	ASSERT(ifp->if_u1.if_extents != NULL);
 	ifp->if_lastex = NULLEXTNUM;
 	ifp->if_bytes = ifp->if_real_bytes = (int)size;
@@ -775,12 +807,12 @@ xfs_iread_extents(
  * being added or deleted as indicated in rec_diff.  Move the records
  * and pointers in if_broot to fit the new size.  When shrinking this
  * will eliminate holes between the records and pointers created by
- * the caller.  When growing this will create holes to be filled in
+ * the caller.	When growing this will create holes to be filled in
  * by the caller.
  *
  * The caller must not request to add more records than would fit in
  * the on-disk inode root.  If the if_broot is currently NULL, then
- * if we adding records one will be allocated.  The caller must also
+ * if we adding records one will be allocated.	The caller must also
  * not request that the number of records go below zero, although
  * it can go to zero.
  *
@@ -790,8 +822,8 @@ xfs_iread_extents(
  */
 void
 xfs_iroot_realloc(
-	xfs_inode_t 		*ip,
-	int 			rec_diff,
+	xfs_inode_t		*ip,
+	int			rec_diff,
 	int			whichfork)
 {
 	int			cur_max;
@@ -832,7 +864,7 @@ xfs_iroot_realloc(
 		cur_max = XFS_BMAP_BROOT_MAXRECS(ifp->if_broot_bytes);
 		new_max = cur_max + rec_diff;
 		new_size = (size_t)XFS_BMAP_BROOT_SPACE_CALC(new_max);
-		ifp->if_broot = (xfs_bmbt_block_t *) 
+		ifp->if_broot = (xfs_bmbt_block_t *)
 		  kmem_realloc(ifp->if_broot,
 				new_size,
 				(size_t)XFS_BMAP_BROOT_SPACE_CALC(cur_max), /* old size */
@@ -844,7 +876,7 @@ xfs_iroot_realloc(
 		ifp->if_broot_bytes = (int)new_size;
 		ASSERT(ifp->if_broot_bytes <=
 			XFS_IFORK_SIZE(ip, whichfork) + XFS_BROOT_SIZE_ADJ);
-		ovbcopy(op, np, cur_max * (uint)sizeof(xfs_dfsbno_t));
+		memmove(np, op, cur_max * (uint)sizeof(xfs_dfsbno_t));
 		return;
 	}
 
@@ -866,7 +898,7 @@ xfs_iroot_realloc(
 		/*
 		 * First copy over the btree block header.
 		 */
-		bcopy(ifp->if_broot, new_broot, sizeof(xfs_bmbt_block_t));
+		memcpy(new_broot, ifp->if_broot, sizeof(xfs_bmbt_block_t));
 	} else {
 		new_broot = NULL;
 		ifp->if_flags &= ~XFS_IFBROOT;
@@ -883,7 +915,7 @@ xfs_iroot_realloc(
 						     ifp->if_broot_bytes);
 		np = (char *)XFS_BMAP_BROOT_REC_ADDR(new_broot, 1,
 						     (int)new_size);
-		bcopy(op, np, new_max * (uint)sizeof(xfs_bmbt_rec_t));	
+		memcpy(np, op, new_max * (uint)sizeof(xfs_bmbt_rec_t));
 
 		/*
 		 * Then copy the pointers.
@@ -892,7 +924,7 @@ xfs_iroot_realloc(
 						     ifp->if_broot_bytes);
 		np = (char *)XFS_BMAP_BROOT_PTR_ADDR(new_broot, 1,
 						     (int)new_size);
-		bcopy(op, np, new_max * (uint)sizeof(xfs_dfsbno_t));
+		memcpy(np, op, new_max * (uint)sizeof(xfs_dfsbno_t));
 	}
 	kmem_free(ifp->if_broot, ifp->if_broot_bytes);
 	ifp->if_broot = new_broot;
@@ -955,8 +987,8 @@ xfs_iext_realloc(
 			 * so the if_extents pointer is null.
 			 */
 			if (ifp->if_u1.if_extents) {
-				bcopy(ifp->if_u1.if_extents,
-				      ifp->if_u2.if_inline_ext, new_size);
+				memcpy(ifp->if_u2.if_inline_ext,
+					ifp->if_u1.if_extents, new_size);
 				kmem_free(ifp->if_u1.if_extents,
 					  ifp->if_real_bytes);
 			}
@@ -973,14 +1005,14 @@ xfs_iext_realloc(
 		if (ifp->if_u1.if_extents == ifp->if_u2.if_inline_ext) {
 			ifp->if_u1.if_extents = (xfs_bmbt_rec_t *)
 				kmem_alloc(rnew_size, KM_SLEEP);
-			bcopy(ifp->if_u2.if_inline_ext, ifp->if_u1.if_extents,
+			memcpy(ifp->if_u1.if_extents, ifp->if_u2.if_inline_ext,
 			      sizeof(ifp->if_u2.if_inline_ext));
 		} else if (rnew_size != ifp->if_real_bytes) {
 			ifp->if_u1.if_extents = (xfs_bmbt_rec_t *)
 			  kmem_realloc(ifp->if_u1.if_extents,
 					rnew_size,
 					ifp->if_real_bytes,
-					KM_SLEEP);
+					KM_NOFS);
 		}
 	}
 	ifp->if_real_bytes = rnew_size;
@@ -1036,7 +1068,7 @@ xfs_idata_realloc(
 			ifp->if_u1.if_data = ifp->if_u2.if_inline_data;
 		} else if (ifp->if_u1.if_data != ifp->if_u2.if_inline_data) {
 			ASSERT(ifp->if_real_bytes != 0);
-			bcopy(ifp->if_u1.if_data, ifp->if_u2.if_inline_data,
+			memcpy(ifp->if_u2.if_inline_data, ifp->if_u1.if_data,
 			      new_size);
 			kmem_free(ifp->if_u1.if_data, ifp->if_real_bytes);
 			ifp->if_u1.if_data = ifp->if_u2.if_inline_data;
@@ -1047,7 +1079,7 @@ xfs_idata_realloc(
 		 * Stuck with malloc/realloc.
 		 * For inline data, the underlying buffer must be
 		 * a multiple of 4 bytes in size so that it can be
-		 * logged and stay on word boundaries.  We enforce
+		 * logged and stay on word boundaries.	We enforce
 		 * that here.
 		 */
 		real_size = roundup(new_size, 4);
@@ -1069,8 +1101,8 @@ xfs_idata_realloc(
 		} else {
 			ASSERT(ifp->if_real_bytes == 0);
 			ifp->if_u1.if_data = kmem_alloc(real_size, KM_SLEEP);
-			bcopy(ifp->if_u2.if_inline_data, ifp->if_u1.if_data,
-			      ifp->if_bytes);
+			memcpy(ifp->if_u1.if_data, ifp->if_u2.if_inline_data,
+				ifp->if_bytes);
 		}
 	}
 	ifp->if_real_bytes = real_size;
@@ -1132,12 +1164,12 @@ xfs_idestroy_fork(
 
 	/*
 	 * If the format is local, then we can't have an extents
-	 * array so just look for an inline data array.  If we're
+	 * array so just look for an inline data array.	 If we're
 	 * not local then we may or may not have an extents list,
 	 * so check and free it up if we do.
 	 */
 	if (XFS_IFORK_FORMAT(ip, whichfork) == XFS_DINODE_FMT_LOCAL) {
-		if ((ifp->if_u1.if_data != ifp->if_u2.if_inline_data) && 
+		if ((ifp->if_u1.if_data != ifp->if_u2.if_inline_data) &&
 		    (ifp->if_u1.if_data != NULL)) {
 			ASSERT(ifp->if_real_bytes != 0);
 			kmem_free(ifp->if_u1.if_data, ifp->if_real_bytes);
@@ -1195,7 +1227,7 @@ xfs_iroundup(
  * returns the number of bytes copied into the buffer.
  *
  * If there are no delayed allocation extents, then we can just
- * bcopy() the extents into the buffer.  Otherwise, we need to
+ * memcpy() the extents into the buffer.  Otherwise, we need to
  * examine each extent in turn and skip those which are delayed.
  */
 int
@@ -1207,9 +1239,6 @@ xfs_iextents_copy(
 	int			copied;
 	xfs_bmbt_rec_32_t	*dest_ep;
 	xfs_bmbt_rec_t		*ep;
-#ifdef DEBUG
-	xfs_exntfmt_t		fmt = XFS_EXTFMT_INODE(ip);
-#endif
 #ifdef XFS_BMAP_TRACE
 	static char		fname[] = "xfs_iextents_copy";
 #endif
@@ -1233,9 +1262,9 @@ xfs_iextents_copy(
 		ASSERT(ifp->if_bytes <= XFS_IFORK_SIZE(ip, whichfork));
 		ASSERT(ifp->if_bytes ==
 		       (XFS_IFORK_NEXTENTS(ip, whichfork) *
-		        (uint)sizeof(xfs_bmbt_rec_t)));
-		bcopy(ifp->if_u1.if_extents, buffer, ifp->if_bytes);
-		xfs_validate_extents(buffer, nrecs, fmt);
+			(uint)sizeof(xfs_bmbt_rec_t)));
+		memcpy(buffer, ifp->if_u1.if_extents, ifp->if_bytes);
+		xfs_validate_extents(buffer, nrecs, XFS_EXTFMT_INODE(ip));
 		return ifp->if_bytes;
 	}
 
@@ -1268,10 +1297,10 @@ xfs_iextents_copy(
 	ASSERT(copied != 0);
 	ASSERT(copied == ip->i_d.di_nextents);
 	ASSERT((copied * (uint)sizeof(xfs_bmbt_rec_t)) <= XFS_IFORK_DSIZE(ip));
-	xfs_validate_extents(buffer, copied, fmt);
+	xfs_validate_extents(buffer, copied, XFS_EXTFMT_INODE(ip));
 
 	return (copied * (uint)sizeof(xfs_bmbt_rec_t));
-}		  
+}
 
 /*
  * Each of the following cases stores data into the same region
@@ -1323,7 +1352,7 @@ xfs_iflush_fork(
 		    (ifp->if_bytes > 0)) {
 			ASSERT(ifp->if_u1.if_data != NULL);
 			ASSERT(ifp->if_bytes <= XFS_IFORK_SIZE(ip, whichfork));
-			bcopy(ifp->if_u1.if_data, cp, ifp->if_bytes);
+			memcpy(cp, ifp->if_u1.if_data, ifp->if_bytes);
 		}
 		if (whichfork == XFS_DATA_FORK) {
 			if (XFS_DIR_SHORTFORM_VALIDATE_ONDISK(mp, dip)) {
@@ -1364,11 +1393,11 @@ xfs_iflush_fork(
 			INT_SET(dip->di_u.di_dev, ARCH_CONVERT, ip->i_df.if_u2.if_rdev);
 		}
 		break;
-		
+
 	case XFS_DINODE_FMT_UUID:
 		if (iip->ili_format.ilf_fields & XFS_ILOG_UUID) {
 			ASSERT(whichfork == XFS_DATA_FORK);
-			bcopy(&ip->i_df.if_u2.if_uuid, &dip->di_u.di_muuid,
+			memcpy(&dip->di_u.di_muuid, &ip->i_df.if_u2.if_uuid,
 				sizeof(uuid_t));
 		}
 		break;
