@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2000-2002 Silicon Graphics, Inc.  All Rights Reserved.
  * 
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -35,6 +35,7 @@
 #include <volume.h>
 #include <mountinfo.h>
 #include <libxfs.h>
+#include <ctype.h>
 
 #include "xfs_mkfs.h"
 #include "maxtrres.h"
@@ -107,12 +108,18 @@ char	*lopts[] = {
 	"internal",
 #define	L_SIZE		2
 	"size",
-#define L_DEV		3
+#define L_VERSION	3
+	"version",
+#define L_SUNIT		4
+	"sunit",
+#define L_SU		5
+	"su",
+#define L_DEV		6
 	"logdev",
 #ifdef MKFS_SIMULATION
-#define	L_FILE		4
+#define	L_FILE		7
 	"file",
-#define	L_NAME		5
+#define	L_NAME		8
 	"name",
 #endif
 	NULL
@@ -258,18 +265,19 @@ static const int max_trres_v2[DFL_B][DFL_I][DFL_D] = {
 	(XFS_BM_MAXLEVELS(mp, XFS_DATA_FORK) - 1) + (rb)))
 
 static void
-calc_stripe_factors(int dsu, int dsw, int *dsunit, int *dswidth)
+calc_stripe_factors(int dsu, int dsw, int lsu, int *dsunit, int *dswidth, int *lsunit)
 {
+	/* Handle data sunit/swidth options */
 	if (*dsunit || *dswidth) {
 		if (dsu || dsw) {
 			fprintf(stderr,
-	"su/sw should not be used in conjunction with sunit/swidth\n");
+	"data su/sw should not be used in conjunction with data sunit/swidth\n");
 			usage();
 		}
 
 		if ((*dsunit && !*dswidth) || (!*dsunit && *dswidth)) {
 			fprintf(stderr,
-	"both sunit and swidth options have to be specified\n");
+	"both data sunit and data swidth options must be specified\n");
 			usage();
 		}
 	}
@@ -277,18 +285,18 @@ calc_stripe_factors(int dsu, int dsw, int *dsunit, int *dswidth)
 	if (dsu || dsw) {
 		if (*dsunit || *dswidth) {
 			fprintf(stderr,
-	"sunit/swidth should not be used in conjunction with su/sw\n");
+	"data sunit/swidth should not be used in conjunction with data su/sw\n");
 			usage();
 		}
 
 		if ((dsu && !dsw) || (!dsu && dsw)) {
 			fprintf(stderr,
-	"both su and sw options have to be specified\n");
+	"both data su and data sw options must be specified\n");
 			usage();
 		}
 
 		if (dsu % BBSIZE) {
-			fprintf(stderr, "su must be a multiple of %d\n",
+			fprintf(stderr, "data su must be a multiple of %d\n",
 								BBSIZE);
 			usage();
 		}
@@ -299,23 +307,36 @@ calc_stripe_factors(int dsu, int dsw, int *dsunit, int *dswidth)
 
 	if (*dsunit && (*dswidth % *dsunit != 0)) {
 		fprintf(stderr,
-	"stripe width (%d) has to be a multiple of the stripe unit (%d)\n",
+	"data stripe width (%d) must be a multiple of the data stripe unit (%d)\n",
 			*dswidth, *dsunit);
 		usage();
 	}
-}
 
-static int
-get_default_blocksize(void)
-{
-	size_t	pagesize = getpagesize();
-	int	i;
+	/* Handle log sunit options */
 
-	/* default is between 4K and 16K */
-	for (i = 12; i <= 16; i++)
-		if ((1 << i) == pagesize)
-			return pagesize;
-	return (1 << XFS_DFL_BLOCKSIZE_LOG);
+	if (*lsunit) {
+		if (lsu) {
+			fprintf(stderr,
+	"log su should not be used in conjunction with log sunit\n");
+			usage();
+		}
+	}
+
+	if (lsu) {
+		if (*lsunit) {
+			fprintf(stderr,
+	"log sunit should not be used in conjunction with log su\n");
+			usage();
+		}
+
+		if (lsu % BBSIZE) {
+			fprintf(stderr, "log su must be a multiple of %d\n",
+							BBSIZE);
+			usage();
+		}
+
+		*lsunit  = (int)BTOBBT(lsu);
+	}
 }
 
 static int
@@ -340,6 +361,53 @@ check_overwrite(char *device)
 	return 0;
 }
 
+xfs_dfsbno_t
+fixup_log_stripe(
+	xfs_mount_t	*mp,
+	int		lsflag,
+	xfs_dfsbno_t	logstart,
+	__uint64_t	agsize,
+	int		sunit,
+	xfs_drfsbno_t	*logblocks,
+	int		blocklog)
+{
+	__uint64_t	tmp_logblocks;
+
+	logstart = ((logstart + (sunit - 1))/sunit) * sunit;
+	/* 
+	 * Make sure that the log size is a multiple of the
+	 * stripe unit
+	 */
+	if ((*logblocks % sunit) != 0) {
+		if (!lsflag) {
+			tmp_logblocks = ((*logblocks + (sunit - 1))
+						/ sunit) * sunit;
+			/*
+			 * If the log is too large, round down
+			 * instead of round up
+			 */
+			if ((tmp_logblocks > XFS_MAX_LOG_BLOCKS) ||
+			    ((tmp_logblocks << blocklog) > XFS_MAX_LOG_BYTES)) {
+				tmp_logblocks = (*logblocks / sunit) * sunit;
+			}
+			*logblocks = tmp_logblocks;
+		} else {
+			fprintf(stderr,
+	"internal log size %lld is not a multiple of the log stripe unit %d\n", 
+					(long long)*logblocks, sunit);
+			usage();
+		}
+	}
+
+	if (*logblocks > agsize-XFS_FSB_TO_AGBNO(mp,logstart)) {
+		fprintf(stderr,
+	"Due to stripe alignment, the internal log size %lld is too large.\n"
+	"Must fit in allocation group\n",
+			(long long)*logblocks);
+		usage();
+	}
+	return logstart;
+}
 
 int
 main(int argc, char **argv)
@@ -394,7 +462,11 @@ main(int argc, char **argv)
 	int			loginternal;
 	char			*logsize;
 	xfs_dfsbno_t		logstart;
+	int			logversion;
+	int			lvflag;
 	int			lsflag;
+	int			lsu;
+	int			lsunit;
 	int			min_logblocks;
 	mnt_check_state_t       *mnt_check_state;
 	int                     mnt_partition_count;
@@ -419,7 +491,6 @@ main(int argc, char **argv)
 	xfs_sb_t		*sbp;
 	int			sectlog;
 	__uint64_t		tmp_agsize;
-	__uint64_t		tmp_logblocks;
 	uuid_t			uuid;
 	int			worst_freelist;
 	libxfs_init_t		xi;
@@ -430,12 +501,12 @@ main(int argc, char **argv)
 	agcount = 8;
 	blflag = bsflag = 0;
 	dasize = daflag = 0;
-	blocksize = get_default_blocksize();
-	blocklog = libxfs_highbit32(blocksize);
+	blocklog = blocksize = 0;
 	agsize = daflag = dblocks = 0;
 	ilflag = imflag = ipflag = isflag = 0;
-	liflag = laflag = lsflag = ldflag = 0;
+	liflag = laflag = lsflag = ldflag = lvflag = 0;
 	loginternal = 1;
+	logversion = 1;
 	logagno = logblocks = rtblocks = 0;
 	nlflag = nsflag = nvflag = 0;
 	dirblocklog = dirblocksize = dirversion = 0;
@@ -448,7 +519,7 @@ main(int argc, char **argv)
 	dfile = logfile = rtfile = NULL;
 	dsize = logsize = rtsize = rtextsize = protofile = NULL;
 	opterr = 0;
-	dsu = dsw = dsunit = dswidth = nodsflag = lalign = 0;
+	dsu = dsw = dsunit = dswidth = nodsflag = lalign = lsu = lsunit = 0;
 	do_overlap_checks = 1;
 	extent_flagging = 0;
 	force_overwrite = 0;
@@ -523,11 +594,7 @@ main(int argc, char **argv)
 						reqval('d', dopts, D_AGSIZE);
 					if (dasize)
 						respec('d', dopts, D_AGSIZE);
-					if (blflag || bsflag)
-						agsize = cvtnum(blocksize,
-								value);
-					else
-						agsize = cvtnum(0, value);
+					agsize = cvtnum(blocksize, value);
 					dasize = 1;
 					break;
 				case D_FILE:
@@ -558,35 +625,45 @@ main(int argc, char **argv)
 						reqval('d', dopts, D_SUNIT);
 					if (dsunit)
 						respec('d', dopts, D_SUNIT);
-					if (blflag || bsflag)
-						dsunit = cvtnum(blocksize,
-								value);
-					else
-						dsunit = cvtnum(0, value);
+					if (!isdigits(value)) {
+						fprintf(stderr,
+		"%s: Specify data sunit in 512-byte blocks, no unit suffix\n",
+							progname);
+						exit(1);
+					}
+					dsunit = cvtnum(0, value);
 					break;
 				case D_SWIDTH:
 					if (!value)
 						reqval('d', dopts, D_SWIDTH);
 					if (dswidth)
 						respec('d', dopts, D_SWIDTH);
-					if (blflag || bsflag)
-						dswidth = cvtnum(blocksize,
-								 value);
-					else
-						dswidth = cvtnum(0, value);
+					if (!isdigits(value)) {
+						fprintf(stderr,
+		"%s: Specify data swidth in 512-byte blocks, no unit suffix\n",
+							progname);
+						exit(1);
+					}
+					dswidth = cvtnum(0, value);
 					break;
 				case D_SU:
 					if (!value)
 						reqval('d', dopts, D_SU);
 					if (dsu)
 						respec('d', dopts, D_SU);
-					dsu = cvtnum(0, value);
+					dsu = cvtnum(blocksize, value);
 					break;
 				case D_SW:
 					if (!value)
 						reqval('d', dopts, D_SW);
 					if (dsw)
 						respec('d', dopts, D_SW);
+					if (!isdigits(value)) {
+						fprintf(stderr,
+		"%s: Specify data sw as multiple of su, no unit suffix\n",
+							progname);
+						exit(1);
+					}
 					dsw = cvtnum(0, value);
 					break;
 				case D_UNWRITTEN:
@@ -750,6 +827,25 @@ main(int argc, char **argv)
 						illegal(value, "l internal");
 					liflag = 1;
 					break;
+				case L_SU:
+					if (!value)
+						reqval('l', lopts, L_SU);
+					if (lsu)
+						respec('l', lopts, L_SU);
+					lsu = cvtnum(blocksize, value);
+					break;
+				case L_SUNIT:
+					if (!value)
+						reqval('l', lopts, L_SUNIT);
+					if (lsunit)
+						respec('l', lopts, L_SUNIT);
+					if (!isdigits(value)) {
+						fprintf(stderr,
+		"Specify log sunit in 512-byte blocks, no size suffix\n");
+						usage();
+					}
+					lsunit = cvtnum(0, value);
+					break;
 #ifdef HAVE_VOLUME_MANAGER
 				case L_NAME:
 					if (!value)
@@ -762,6 +858,16 @@ main(int argc, char **argv)
 					xi.logname = value;
 					break;
 #endif
+				case L_VERSION:
+					if (!value)
+						reqval('n', nopts, L_VERSION);
+					if (lvflag)
+						respec('n', nopts, L_VERSION);
+					logversion = atoi(value);
+					if (logversion < 1 || logversion > 2)
+						illegal(value, "l version");
+					lvflag = 1;
+					break;
 				case L_SIZE:
 					if (!value)
 						reqval('l', lopts, L_SIZE);
@@ -909,6 +1015,13 @@ main(int argc, char **argv)
 	} else
 		dfile = xi.dname;
 	/* option post-processing */
+	/*
+	 * blocksize first, other things depend on it
+	 */
+	if (!blflag && !bsflag) {
+		blocklog = XFS_DFL_BLOCKSIZE_LOG;
+		blocksize = 1 << XFS_DFL_BLOCKSIZE_LOG;
+	}
 	if (blocksize < XFS_MIN_BLOCKSIZE || blocksize > XFS_MAX_BLOCKSIZE) {
 		fprintf(stderr, "illegal block size %d\n", blocksize);
 		usage();
@@ -1104,7 +1217,13 @@ main(int argc, char **argv)
 		usage();
 	}
 
-	calc_stripe_factors(dsu, dsw, &dsunit, &dswidth);
+	/* if lsu or lsunit was specified, automatically use v2 logs */
+	if ((lsu || lsunit) && logversion == 1) {
+		fprintf(stderr, "log stripe unit specified, using v2 logs\n");
+		logversion = 2;
+	}
+
+	calc_stripe_factors(dsu, dsw, lsu, &dsunit, &dswidth, &lsunit);
 
 	/* other global variables */
 	sectlog = 9;		/* i.e. 512 bytes */
@@ -1367,12 +1486,13 @@ main(int argc, char **argv)
 			usage();
 		}
 		agsize = XFS_AG_MIN_BLOCKS(blocklog);
-		if (dblocks < agsize)
+		if (dblocks < agsize) {
 			agcount = 1;
-		else
+			agsize = dblocks;
+		} else {
 			agcount = dblocks / agsize;
-
-		agsize = dblocks / agcount + (dblocks % agcount != 0);
+			agsize = dblocks / agcount +(dblocks % agcount != 0);
+		}
 	}
 
 	/*
@@ -1395,12 +1515,14 @@ main(int argc, char **argv)
 	}
 
 	/*
-	 * if user set the AG size, and if the last AG is too small,
-	 * reduce the filesystem size and drop the blocks.
+	 * If the last AG is too small, reduce the filesystem size
+	 * and drop the blocks.
 	 */
-	if (!daflag &&
-	    (dblocks % agsize < XFS_AG_MIN_BLOCKS(blocklog))) {
-		dblocks -= dblocks % agsize;
+	if ( dblocks % agsize != 0 &&
+	     (dblocks % agsize < XFS_AG_MIN_BLOCKS(blocklog))) {
+		dblocks = (xfs_drfsbno_t)((agcount - 1) * agsize);
+		agcount--;
+		ASSERT(agcount != 0);
 	}
 
 	/*
@@ -1410,14 +1532,17 @@ main(int argc, char **argv)
 	if (!daflag && !dasize &&
 	    (agsize > XFS_AG_BEST_BLOCKS(blocklog,dblocks))) {
 		agsize = XFS_AG_BEST_BLOCKS(blocklog,dblocks);
+		agcount = dblocks / agsize + (dblocks % agsize != 0);
 		/*
 		 * If the last AG is too small, reduce the filesystem size
 		 * and drop the blocks.
 		 */
-		if (dblocks % agsize < XFS_AG_MIN_BLOCKS(blocklog)) {
-			dblocks -= dblocks % agsize;
+		if ( dblocks % agsize != 0 &&
+		    (dblocks % agsize < XFS_AG_MIN_BLOCKS(blocklog))) {
+			dblocks = (xfs_drfsbno_t)((agcount - 1) * agsize);
+			agcount--;
+			ASSERT(agcount != 0);
 		}
-		agcount = dblocks / agsize + (dblocks % agsize != 0);
 	}
 
 	/*
@@ -1453,13 +1578,11 @@ main(int argc, char **argv)
 			fprintf(stderr, "%s: "
   "Specified data stripe unit %d is not the same as the xlv stripe unit %d\n", 
 				progname, dsunit, xlv_dsunit);
-			exit(1);
 		}
 		if (xlv_dswidth && xlv_dswidth != dswidth) {
 			fprintf(stderr, "%s: "
-"Specified data stripe width (%d) is not the same as the xlv stripe width (%d)\n",
+"Specified data stripe width %d is not the same as the xlv stripe width %d\n",
 				progname, dswidth, xlv_dswidth);
-			exit(1);
 		}
 	} else {
 		dsunit = xlv_dsunit;
@@ -1515,17 +1638,79 @@ main(int argc, char **argv)
 				}
         		}
 		}
+		if (((agsize % dswidth) == 0) && (agcount > 1)) {
+			/* This is a non-optimal configuration because all AGs
+			 * start on the same disk in the stripe.  Changing 
+			 * the AG size by one sunit will guarantee that this
+			 * does not happen.
+			 */
+			tmp_agsize = agsize - dsunit;
+			if (tmp_agsize < XFS_AG_MIN_BLOCKS(blocklog)) {
+				tmp_agsize = agsize + dsunit;
+				if (dblocks < agsize) {
+					/* oh well, nothing to do */
+					tmp_agsize = agsize;
+				}
+			}
+			if (daflag || dasize) {
+				fprintf(stderr,
+"Warning: AG size is a multiple of stripe width.  This can cause performance\n\
+problems by aligning all AGs on the same disk.  To avoid this, run mkfs with\n\
+an AG size that is one stripe unit smaller, for example %llu\n",
+					(unsigned long long)tmp_agsize);
+			} else {
+				agsize = tmp_agsize;
+				agcount = dblocks/agsize + (dblocks % agsize != 0);
+				/*
+				 * If the last AG is too small, reduce the
+				 * filesystem size and drop the blocks.
+				 */
+				if ( dblocks % agsize != 0 &&
+				    (dblocks % agsize <
+				    XFS_AG_MIN_BLOCKS(blocklog))) {
+					dblocks = (xfs_drfsbno_t)((agcount - 1) * agsize);
+					agcount--;
+					ASSERT(agcount != 0);
+				}
+			}
+		}
 	} else {
 		if (nodsflag)
 			dsunit = dswidth = 0;
 		else { 
 			fprintf(stderr, "%s: "
 "Stripe unit(%d) or stripe width(%d) is not a multiple of the block size(%d)\n",
-				progname, dsunit, dswidth, blocksize); 	
+				progname, BBTOB(dsunit), BBTOB(dswidth), 
+				blocksize); 	
 			exit(1);
 		}
 	}
 
+	/*
+	 * check that log sunit is modulo fsblksize or default it to dsunit.
+	 */
+
+	if (lsunit) {
+		if ((BBTOB(lsunit) % blocksize != 0)) {
+			fprintf(stderr,
+"log stripe unit (%d) must be a multiple of the block size (%d)\n",
+			BBTOB(lsunit), blocksize);
+			exit(1);
+		}
+		/* convert from 512 byte blocks to fs blocks */
+		lsunit = DTOBT(lsunit);
+	} else if (dsunit) {
+		/* lsunit and dsunit now in fs blocks */
+		lsunit = dsunit;
+	}
+
+	if ((lsunit * blocksize) > 256 * 1024) {
+		fprintf(stderr,
+"log stripe unit (%d bytes) is too large for kernel to handle (max 256k)\n", 
+			(lsunit * blocksize));
+		exit(1);
+	}
+
 	protostring = setup_proto(protofile);
 	bsize = 1 << (blocklog - BBSHIFT);
 	mp = &mbuf;
@@ -1535,6 +1720,14 @@ main(int argc, char **argv)
 	sbp->sb_agblklog = (__uint8_t)libxfs_log2_roundup((unsigned int)agsize);
 	mp->m_blkbb_log = sbp->sb_blocklog - BBSHIFT;
 	if (loginternal) {
+		/*
+		 * Readjust the log size to fit within an AG if it was sized
+		 * automaticly.
+		 */
+		if (!logsize) {
+			logblocks = MIN(logblocks,
+					agsize - XFS_PREALLOC_BLOCKS(mp));
+		}
 		if (logblocks > agsize - XFS_PREALLOC_BLOCKS(mp)) {
 			fprintf(stderr,
 	"internal log size %lld too large, must fit in allocation group\n",
@@ -1555,40 +1748,15 @@ main(int argc, char **argv)
 		/*
 		 * Align the logstart at stripe unit boundary.
 		 */
-		if (dsunit && ((logstart % dsunit) != 0)) {
-			logstart = ((logstart + (dsunit - 1))/dsunit) * dsunit;
-			/* 
-			 * Make sure that the log size is a multiple of the
-			 * stripe unit
-			 */
-			if ((logblocks % dsunit) != 0) {
-			    if (!lsflag) {
-				tmp_logblocks = ((logblocks + (dsunit - 1))
-							/ dsunit) * dsunit;
-				/*
-				 * If the log is too large, round down
-				 * instead of round up
-				 */
-				if ((tmp_logblocks > XFS_MAX_LOG_BLOCKS) ||
-				    ((tmp_logblocks << blocklog) > XFS_MAX_LOG_BYTES)) {
-					tmp_logblocks = (logblocks / dsunit) * dsunit;
-				}
-				logblocks = tmp_logblocks;
-			    } else {
-				fprintf(stderr,
-	"internal log size %lld is not a multiple of the stripe unit %d\n", 
-					(long long)logblocks, dsunit);
-				usage();
-			    }
-			}
 
-			if (logblocks > agsize-XFS_FSB_TO_AGBNO(mp,logstart)) {
-				fprintf(stderr,
-	"Due to stripe alignment, the internal log size %lld is too large.\n"
-	"Must fit in allocation group\n",
-					(long long)logblocks);
-				usage();
-			}
+		if (lsunit && ((logstart % lsunit) != 0)) {
+			logstart = fixup_log_stripe(mp, lsflag, logstart,
+					agsize, lsunit, &logblocks, blocklog);
+			lalign = 1;
+		} else if (dsunit && ((logstart % dsunit) != 0)) {
+			logstart = fixup_log_stripe(mp, lsflag, logstart,
+					agsize, dsunit, &logblocks,
+					blocklog);
 			lalign = 1;
 		}
 	} else
@@ -1632,6 +1800,10 @@ main(int argc, char **argv)
 	sbp->sb_width = dswidth;
 	if (dirversion == 2)
 		sbp->sb_dirblklog = dirblocklog - blocklog;
+	if (logversion == 2)	/* This is stored in bytes */
+		sbp->sb_logsunit = (lsunit == 0) ? 1 : XFS_FSB_TO_B(mp, lsunit);
+	else
+		sbp->sb_logsunit = 0;
 	if (iaflag) {
 		sbp->sb_inoalignmt = XFS_INODE_BIG_CLUSTER_SIZE >> blocklog;
 		iaflag = sbp->sb_inoalignmt != 0;
@@ -1639,7 +1811,7 @@ main(int argc, char **argv)
 		sbp->sb_inoalignmt = 0;
 	sbp->sb_versionnum =
 		XFS_SB_VERSION_MKFS(iaflag, dsunit != 0, extent_flagging,
-			dirversion == 2);
+			dirversion == 2, logversion == 2);
 
 	/*
 	 * Zero out the first 68k in on the device, to obliterate any old 
@@ -1665,13 +1837,15 @@ main(int argc, char **argv)
 		   "data     =%-22s bsize=%-6d blocks=%lld, imaxpct=%d\n"
 		   "         =%-22s sunit=%-6d swidth=%d blks, unwritten=%d\n"
 		   "naming   =version %-14d bsize=%-6d\n"
-		   "log      =%-22s bsize=%-6d blocks=%lld\n"
+		   "log      =%-22s bsize=%-6d blocks=%lld, version=%d\n"
+		   "         =%-22s sunit=%d blks\n"
 		   "realtime =%-22s extsz=%-6d blocks=%lld, rtextents=%lld\n",
 			dfile, isize, (long long)agcount, (long long)agsize,
 			"", blocksize, (long long)dblocks, sbp->sb_imax_pct,
 			"", dsunit, dswidth, extent_flagging,
 			dirversion, dirversion == 1 ? blocksize : dirblocksize,
 			logfile, 1 << blocklog, (long long)logblocks,
+			logversion, "", lsunit,
 			rtfile, rtextblocks << blocklog,
 			(long long)rtblocks, (long long)rtextents);
 	/*
@@ -1707,11 +1881,11 @@ main(int argc, char **argv)
                     XFS_FSB_TO_DADDR(mp, logstart),
 		    (xfs_extlen_t)XFS_FSB_TO_BB(mp, logblocks),
                     &sbp->sb_uuid,
-                    XLOG_FMT);
+                    logversion, lsunit, XLOG_FMT);
 
 	mp = libxfs_mount(mp, sbp, xi.ddev, xi.logdev, xi.rtdev, 1);
-	if (!mp) {
-		fprintf(stderr, "%s: mount initialization failed\n", progname);
+	if (mp == NULL) {
+		fprintf(stderr, "%s: filesystem failed to initialize\n", progname);
 		exit(1);
 	}
 	if (xi.logdev &&
@@ -2059,6 +2233,21 @@ max_trans_res(
 	return rval;
 }
 
+/* returns 1 if string contains nothing but [0-9], 0 otherwise */
+
+int
+isdigits(char *str)
+{
+	int	i;
+	int	n = strlen(str);
+
+	for (i = 0; i < n; i++) {
+		if (!isdigit(str[i]))
+			return 0;
+	}
+	return 1;
+}
+
 long long
 cvtnum(
 	int		blocksize,
@@ -2082,6 +2271,8 @@ cvtnum(
 		usage();
 	}
 
+	if (*sp == 's' && sp[1] == '\0')
+		return 512LL * i;
 	if (*sp == 'k' && sp[1] == '\0')
 		return 1024LL * i;
 	if (*sp == 'm' && sp[1] == '\0')
@@ -2097,11 +2288,12 @@ usage(void)
 	fprintf(stderr, "Usage: %s\n\
 /* blocksize */		[-b log=n|size=num]\n\
 /* data subvol */	[-d agcount=n,agsize=n,file,name=xxx,size=num,\n\
-			    sunit=value,swidth=value,unwritten=0|1,\n\
-			    su=value,sw=value]\n\
+			    (sunit=value,swidth=value|su=num,sw=num),\n\
+			    unwritten=0|1]\n\
 /* inode size */	[-i log=n|perblock=n|size=num,maxpct=n]\n\
-/* log subvol */	[-l agnum=n,internal,size=num,logdev=xxx]\n\
-/* naming */		[-n log=n|size=num|version=n]\n\
+/* log subvol */	[-l agnum=n,internal,size=num,logdev=xxx\n\
+			    version=n,sunit=value|su=num]\n\
+/* naming */		[-n log=n|size=num,version=n]\n\
 /* label */		[-L label (maximum 12 characters)]\n\
 /* prototype file */	[-p fname]\n\
 /* quiet */		[-q]\n\
@@ -2113,7 +2305,8 @@ Internal log by default, size is scaled from 1,000 blocks to 32,768 blocks\n\
 based on the filesystem size.  Default log reaches its largest size at 1TB.\n\
 This can be overridden with the -l options or using a volume manager with a\n\
 log subvolume.\n\
-<num> is xxx (bytes), or xxxb (blocks), or xxxk (xxx KB), or xxxm (xxx MB)\n\
+<num> is xxx (bytes), xxxs (512 blocks), xxxb (fs blocks), xxxk (xxx KB),\n\
+      or xxxm (xxx MB)\n\
 <value> is xxx (512 blocks).\n",
 		progname);
 	exit(1);
