@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2000-2002 Silicon Graphics, Inc.  All Rights Reserved.
  * 
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -237,7 +237,8 @@ longform_delete_orphanage(xfs_mount_t	*mp,
 	res = 0;
 
 	do {
-		ASSERT(fsbno != NULLDFSBNO);
+		if (fsbno == NULLDFSBNO)
+			break;
 		bp = libxfs_readbuf(mp->m_dev, XFS_FSB_TO_DADDR(mp, fsbno),
 					XFS_FSB_TO_BB(mp, 1), 0);
 		if (!bp) {
@@ -1293,7 +1294,7 @@ block %d\n",
 		/*
 		 * now reset the bitmap for all ags
 		 */
-		bzero(ba_bmap[i], roundup(mp->m_sb.sb_agblocks*(NBBY/XR_BB),
+		bzero(ba_bmap[i], roundup(mp->m_sb.sb_agblocks/(NBBY/XR_BB),
 						sizeof(__uint64_t)));
 		for (j = 0; j < ag_hdr_block; j++)
 			set_agbno_state(mp, i, j, XR_E_INUSE_FS);
